# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as BaseProvider


class Provider(BaseProvider):
    jobs = [
        "Agent celny",
        "Agent firmy inwestycyjnej",
        "Agent literacki",
        "Agent ubezpieczeniowy",
        "Agronom",
        "Aktor",
        "Aktor dziecięcy",
        "Aktor głosowy",
        "Aktuariusz",
        "Animator kultury",
        "Ankieter",
        "Antykwariusz",
        "Arborysta",
        "Archeolog",
        "Architekt krajobrazu",
        "Architekt wnętrz",
        "Archiwista",
        "Artysta-rezydent",
        "Astronom",
        "Audytor efektywności energetycznej",
        "Babcia klozetowa",
        "Bankowiec",
        "Barista",
        "Barman",
        "Bibliotekarz",
        "Bibliotekarz dyplomowany",
        "Biegły rewident",
        "Brakarz",
        "Broker",
        "Broker informacji",
        "Broker ubezpieczeniowy",
        "Certyfikator energetyczny",
        "Charakteryzator",
        "Detektyw",
        "Deweloper budowlany",
        "Doker",
        "Doradca finansowy",
        "Doradca inwestycyjny",
        "Doradca podatkowy w Polsce",
        "Doradca ubezpieczeniowy",
        "Drwal",
        "Dubler",
        "Dyplomata",
        "Dyrektor artystyczny",
        "Dyrektor finansowy",
        "Dyrektor kreatywny",
        "Dziennikarz",
        "Dżokej",
        "Ebenista",
        "Ekonomista",
        "Ekwilibrystyka",
        "Elektromonter pomiarów",
        "Ergonomista",
        "Fasowacz",
        "Finansista",
        "Fotoreporter",
        "Geodeta",
        "Geolog",
        "Główny księgowy",
        "Grabarz",
        "Handlarz",
        "Hostessa",
        "Hutnik",
        "Hycel",
        "Hydraulik",
        "Iluzjonista",
        "Inscenizator",
        "Instruktor",
        "Integrator automatyki",
        "Intendent",
        "Inżynier",
        "Inżynier budownictwa",
        "Kasjer biletowy",
        "Katecheta",
        "Kawalkator",
        "Kawiarka",
        "Kelner",
        "Kierowca",
        "Kiper",
        "Klechdarz",
        "Konferansjer",
        "Koniarze",
        "Konserwator zabytków",
        "Konsjerż",
        "Konstruktor",
        "Konsultant",
        "Konsultant ślubny",
        "Kontroler biletów",
        "Kornak",
        "Kosmonauta",
        "Kostiumograf",
        "Kosztorysant",
        "Kowboj",
        "Krojczy",
        "Krupier",
        "Ksiądz",
        "Księgowy",
        "Kuk",
        "Kupiec",
        "Kurator sądowy",
        "Kurator sztuki",
        "Kurier",
        "Kurier rowerowy",
        "Lalkarz",
        "Leśniczy",
        "Liczmen",
        "Likwidator szkód",
        "Listonosz",
        "Łącznik",
        "Makler giełd towarowych",
        "Makler morski",
        "Makler nadzorujący",
        "Makler papierów wartościowych",
        "Marketingowiec",
        "Marynarz",
        "Masztalerz",
        "Menedżer kultury",
        "Meteorolog",
        "Mim",
        "Model",
        "Modelka dużych rozmiarów",
        "Motorniczy",
        "Nadleśniczy",
        "Nauczyciel",
        "Nauczyciel akademicki",
        "Naukowiec",
        "Niania",
        "Oceanonauta",
        "Ochroniarz",
        "Pakowacz",
        "Palacz",
        "Perfumiarz",
        "Pisarz",
        "Plastyk",
        "Podleśniczy",
        "Poganiacz",
        "Pokojówka",
        "Politolog",
        "Polityk",
        "Portier",
        "Pośrednik finansowy",
        "Pośrednik ubezpieczeniowy",
        "Pośrednik w obrocie nieruchomościami",
        "Pracownicy uczelni w Polsce",
        "Pracownik socjalny",
        "Prezenter",
        "Producent wykonawczy",
        "Projektant gier komputerowych",
        "Przedstawiciel handlowy",
        "Przewodnik turystyczny",
        "Psiarz",
        "Psycholog",
        "Pucybut",
        "Rachmistrz",
        "Ratownik",
        "Ratownik przedmedyczny",
        "Redaktor",
        "Redaktor merytoryczny",
        "Redaktor naukowy",
        "Redaktor techniczny",
        "Rekwizytor",
        "Reporter wojenny",
        "Reżyser",
        "Robotnik",
        "Rolnik",
        "Rybak",
        "Rzecznik prasowy",
        "Rzeczoznawca",
        "Rzeczoznawca budowlany",
        "Rzeczoznawca majątkowy",
        "Rzeczoznawca samochodowy",
        "Salowa",
        "Satyryk",
        "Scenarzysta",
        "Scenograf",
        "Służący",
        "Sprzątacz",
        "Sprzedawca",
        "Stajenny",
        "Strażak",
        "Sufler",
        "Supermodelka",
        "Syndyk",
        "Syndyk licencjonowany",
        "Szatniarz",
        "Szczurołap",
        "Szlifierz",
        "Sztygar",
        "Taksówkarz",
        "Technik awionik",
        "Technik budownictwa",
        "Technik elektronik",
        "Technik handlowiec",
        "Technik kelner",
        "Technik mechanik",
        "Technik mechanik lotniczy",
        "Technik mechanik okrętowy",
        "Technik nawigator morski",
        "Technik ochrony środowiska",
        "Technik technologii drewna",
        "Technik weterynarii",
        "Technik żywienia i gospodarstwa domowego",
        "Teksturator",
        "Terapeuta",
        "Terminolog",
        "Tłumacz",
        "Tłumacz literacki",
        "Tłumacz przysięgły",
        "Tokarz",
        "Trener",
        "Trener personalny",
        "Urbanista",
        "Lekarz weterynarii",
        "Wydawca",
        "Zarządca nieruchomości",
        "Zoopsycholog",
        "Żołnierz",
        "Żongler",
    ]



# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as AddressProvider


class Provider(AddressProvider):
    city_prefixes = ('San', 'Borgo', 'Sesto', 'Quarto', 'Settimo')
    city_suffixes = ('a mare', 'lido', 'ligure', 'del friuli', 'salentino',
                     'calabro', 'veneto', 'nell\'emilia', 'umbro', 'laziale',
                     'terme', 'sardo')
    building_number_formats = ('###', '##', '#')
    street_suffixes = ('Piazza', 'Strada', 'Via', 'Borgo', 'Contrada',
                       'Rotonda', 'Incrocio', 'Viale', 'Stretto', 'Vicolo',
                       'Canale')
    postcode_formats = ('#####', )
    states = ('Agrigento', 'Alessandria', 'Ancona', 'Aosta', 'Arezzo',
              'Ascoli Piceno', 'Asti', 'Avellino', 'Bari',
              'Barletta-Andria-Trani', 'Belluno', 'Benevento', 'Bergamo',
              'Biella', 'Bologna', 'Bolzano', 'Brescia', 'Brindisi',
              'Cagliari', 'Caltanissetta', 'Campobasso', 'Carbonia-Iglesias',
              'Caserta', 'Catania', 'Catanzaro', 'Chieti', 'Como', 'Cosenza',
              'Cremona', 'Crotone', 'Cuneo', 'Enna', 'Fermo', 'Ferrara',
              'Firenze', 'Foggia', 'Forlì-Cesena', 'Frosinone', 'Genova',
              'Gorizia', 'Grosseto', 'Imperia', 'Isernia', 'La Spezia',
              'L\'Aquila', 'Latina', 'Lecce', 'Lecco', 'Livorno', 'Lodi',
              'Lucca', 'Macerata', 'Mantova', 'Massa-Carrara', 'Matera',
              'Messina', 'Milano', 'Modena', 'Monza e della Brianza', 'Napoli',
              'Novara', 'Nuoro', 'Olbia-Tempio', 'Oristano', 'Padova',
              'Palermo', 'Parma', 'Pavia', 'Perugia', 'Pesaro e Urbino',
              'Pescara', 'Piacenza', 'Pisa', 'Pistoia', 'Pordenone', 'Potenza',
              'Prato', 'Ragusa', 'Ravenna', 'Reggio Calabria', 'Reggio Emilia',
              'Rieti', 'Rimini', 'Roma', 'Rovigo', 'Salerno',
              'Medio Campidano', 'Sassari', 'Savona', 'Siena', 'Siracusa',
              'Sondrio', 'Taranto', 'Teramo', 'Terni', 'Torino', 'Ogliastra',
              'Trapani', 'Trento', 'Treviso', 'Trieste', 'Udine', 'Varese',
              'Venezia', 'Verbano-Cusio-Ossola', 'Vercelli', 'Verona',
              'Vibo Valentia', 'Vicenza', 'Viterbo')
    states_abbr = ('AG', 'AL', 'AN', 'AO', 'AR', 'AP', 'AT', 'AV', 'BA', 'BT',
                   'BL', 'BN', 'BG', 'BI', 'BO', 'BZ', 'BS', 'BR', 'CA', 'CL',
                   'CB', 'CI', 'CE', 'CT', 'CZ', 'CH', 'CO', 'CS', 'CR', 'KR',
                   'CN', 'EN', 'FM', 'FE', 'FI', 'FG', 'FC', 'FR', 'GE', 'GO',
                   'GR', 'IM', 'IS', 'SP', 'AQ', 'LT', 'LE', 'LC', 'LI', 'LO',
                   'LU', 'MC', 'MN', 'MS', 'MT', 'ME', 'MI', 'MO', 'MB', 'NA',
                   'NO', 'NU', 'OT', 'OR', 'PD', 'PA', 'PR', 'PV', 'PG', 'PU',
                   'PE', 'PC', 'PI', 'PT', 'PN', 'PZ', 'PO', 'RG', 'RA', 'RC',
                   'RE', 'RI', 'RN', 'RM', 'RO', 'SA', 'VS', 'SS', 'SV', 'SI',
                   'SR', 'SO', 'TA', 'TE', 'TR', 'TO', 'OG', 'TP', 'TN', 'TV',
                   'TS', 'UD', 'VA', 'VE', 'VB', 'VC', 'VR', 'VV', 'VI', 'VT')
    countries = (
        'Afghanistan', 'Albania', 'Algeria', 'American Samoa', 'Andorra',
        'Angola', 'Anguilla', 'Antartide (territori a sud del 60° parallelo)',
        'Antigua e Barbuda', 'Argentina', 'Armenia', 'Aruba', 'Australia',
        'Austria', 'Azerbaijan', 'Bahamas', 'Bahrain', 'Bangladesh',
        'Barbados', 'Bielorussia', 'Belgio', 'Belize', 'Benin', 'Bermuda',
        'Bhutan', 'Bolivia', 'Bosnia e Herzegovina', 'Botswana',
        'Bouvet Island (Bouvetoya)', 'Brasile',
        'Territorio dell\'arcipelago indiano', 'Isole Vergini Britanniche',
        'Brunei Darussalam', 'Bulgaria', 'Burkina Faso', 'Burundi', 'Cambogia',
        'Cameroon', 'Canada', 'Capo Verde', 'Isole Cayman',
        'Repubblica Centrale Africana', 'Chad', 'Cile', 'Cina',
        'Isola di Pasqua', 'Isola di Cocos (Keeling)', 'Colombia', 'Comoros',
        'Congo', 'Isole Cook', 'Costa Rica', 'Costa d\'Avorio', 'Croazia',
        'Cuba', 'Cipro', 'Repubblica Ceca', 'Danimarca', 'Gibuti',
        'Repubblica Dominicana', 'Equador', 'Egitto', 'El Salvador',
        'Guinea Equatoriale', 'Eritrea', 'Estonia', 'Etiopia', 'Isole Faroe',
        'Isole Falkland (Malvinas)', 'Fiji', 'Finlandia', 'Francia',
        'Guyana Francese', 'Polinesia Francese', 'Territori Francesi del sud',
        'Gabon', 'Gambia', 'Georgia', 'Germania', 'Ghana', 'Gibilterra',
        'Grecia', 'Groenlandia', 'Grenada', 'Guadalupa', 'Guam', 'Guatemala',
        'Guernsey', 'Guinea', 'Guinea-Bissau', 'Guyana', 'Haiti',
        'Heard Island and McDonald Islands', 'Città del Vaticano', 'Honduras',
        'Hong Kong', 'Ungheria', 'Islanda', 'India', 'Indonesia', 'Iran',
        'Iraq', 'Irlanda', 'Isola di Man', 'Israele', 'Italia', 'Giamaica',
        'Giappone', 'Jersey', 'Giordania', 'Kazakhstan', 'Kenya', 'Kiribati',
        'Korea', 'Kuwait', 'Republicca Kirgiza', 'Repubblica del Laos',
        'Latvia', 'Libano', 'Lesotho', 'Liberia', 'Libyan Arab Jamahiriya',
        'Liechtenstein', 'Lituania', 'Lussemburgo', 'Macao', 'Macedonia',
        'Madagascar', 'Malawi', 'Malesia', 'Maldive', 'Mali', 'Malta',
        'Isole Marshall', 'Martinica', 'Mauritania', 'Mauritius', 'Mayotte',
        'Messico', 'Micronesia', 'Moldova', 'Principato di Monaco', 'Mongolia',
        'Montenegro', 'Montserrat', 'Marocco', 'Mozambico', 'Myanmar',
        'Namibia', 'Nauru', 'Nepal', 'Antille Olandesi', 'Olanda',
        'Nuova Caledonia', 'Nuova Zelanda', 'Nicaragua', 'Niger', 'Nigeria',
        'Niue', 'Isole Norfolk', 'Northern Mariana Islands', 'Norvegia',
        'Oman', 'Pakistan', 'Palau', 'Palestina', 'Panama',
        'Papua Nuova Guinea', 'Paraguay', 'Peru', 'Filippine',
        'Pitcairn Islands', 'Polonia', 'Portogallo', 'Porto Rico', 'Qatar',
        'Reunion', 'Romania', 'Russia', 'Rwanda', 'San Bartolomeo',
        'Sant\'Elena', 'Saint Kitts and Nevis', 'Saint Lucia', 'Saint Martin',
        'Saint Pierre and Miquelon', 'Saint Vincent and the Grenadines',
        'Samoa', 'San Marino', 'Sao Tome and Principe', 'Arabia Saudita',
        'Senegal', 'Serbia', 'Seychelles', 'Sierra Leone', 'Singapore',
        'Slovenia', 'Isole Solomon', 'Somalia', 'Sud Africa',
        'Georgia del sud e South Sandwich Islands', 'Spagna', 'Sri Lanka',
        'Sudan', 'Suriname', 'Svalbard & Jan Mayen Islands', 'Swaziland',
        'Svezia', 'Svizzera', 'Siria', 'Taiwan', 'Tajikistan', 'Tanzania',
        'Tailandia', 'Timor-Leste', 'Togo', 'Tokelau', 'Tonga',
        'Trinidad e Tobago', 'Tunisia', 'Turchia', 'Turkmenistan',
        'Isole di Turks and Caicos', 'Tuvalu', 'Uganda', 'Ucraina',
        'Emirati Arabi Uniti', 'Regno Unito', 'Stati Uniti d\'America',
        'United States Minor Outlying Islands', 'Isole Vergini Statunitensi',
        'Uruguay', 'Uzbekistan', 'Vanuatu', 'Venezuela', 'Vietnam',
        'Wallis and Futuna', 'Western Sahara', 'Yemen', 'Zambia', 'Zimbabwe')

    city_formats = ('{{city_prefix}} {{first_name}} {{city_suffix}}',
                    '{{city_prefix}} {{first_name}}',
                    '{{first_name}} {{city_suffix}}',
                    '{{last_name}} {{city_suffix}}')
    street_name_formats = ('{{street_suffix}} {{first_name}}',
                           '{{street_suffix}} {{last_name}}')
    street_address_formats = (
        '{{street_name}} {{building_number}}',
        '{{street_name}} {{building_number}} {{secondary_address}}')
    address_formats = (
        "{{street_address}}\n{{city}}, {{postcode}} {{state}} ({{state_abbr}})",
    )
    secondary_address_formats = ('Appartamento ##', 'Piano #')

    def city_prefix(self):
        return self.random_element(self.city_prefixes)

    def secondary_address(self):
        return self.numerify(
            self.random_element(self.secondary_address_formats))

    def state(self):
        return self.random_element(self.states)

    def state_abbr(self):
        return self.random_element(self.states_abbr)



# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as AddressProvider


class Provider(AddressProvider):
    street_prefixes = ('Av', 'Avenida', 'R.', 'Rua', 'Travessa', 'Largo')

    city_formats = ('{{city_name}}',)
    street_name_formats = (
        '{{street_prefix}} {{last_name}}',
        '{{street_prefix}} {{first_name}} {{last_name}}',
        '{{street_prefix}} de {{last_name}}',
    )

    street_address_formats = (
        '{{street_name}}, {{building_number}}',
    )

    address_formats = (
        "{{street_address}}\n{{postcode}} {{city}}",
    )

    building_number_formats = ('S/N', '%', '%#', '%#', '%#', '%##')

    postcode_formats = ('####-###',)

    cities = (
        'Abrantes', 'Agualva-Cacém', 'Albufeira', 'Alcobaça', 'Alcácer do Sal',
        'Almada', 'Almeirim', 'Alverca do Ribatejo', 'Amadora', 'Amarante',
        'Amora', 'Anadia', 'Angra do Heroísmo', 'Aveiro', 'Barcelos',
        'Barreiro', 'Beja', 'Braga', 'Bragança', 'Caldas da Rainha', 'Caniço',
        'Cantanhede', 'Cartaxo', 'Castelo Branco', 'Chaves', 'Coimbra',
        'Costa da Caparica', 'Covilhã', 'Câmara de Lobos', 'Elvas',
        'Entroncamento', 'Ermesinde', 'Esmoriz', 'Espinho', 'Esposende',
        'Estarreja', 'Estremoz', 'Fafe', 'Faro', 'Felgueiras',
        'Figueira da Foz', 'Fiães', 'Freamunde', 'Funchal', 'Fundão', 'Fátima',
        'Gafanha da Nazaré', 'Gandra', 'Gondomar', 'Gouveia', 'Guarda',
        'Guimarães', 'Horta', 'Lagoa', 'Lagos', 'Lamego', 'Leiria', 'Lisboa',
        'Lixa', 'Loulé', 'Loures', 'Lourosa', 'Macedo de Cavaleiros', 'Maia',
        'Mangualde', 'Marco de Canaveses', 'Marinha Grande', 'Matosinhos',
        'Mealhada', 'Miranda do Douro', 'Mirandela', 'Montemor-o-Novo',
        'Montijo', 'Moura', 'Mêda', 'Odivelas', 'Olhão', 'Oliveira de Azeméis',
        'Oliveira do Bairro', 'Oliveira do Hospital', 'Ourém', 'Ovar',
        'Paredes', 'Paços de Ferreira', 'Penafiel', 'Peniche', 'Peso da Régua',
        'Pinhel', 'Pombal', 'Ponta Delgada', 'Ponte de Sor', 'Portalegre',
        'Portimão', 'Porto', 'Porto Santo', 'Praia da Vitória',
        'Póvoa de Santa Iria', 'Póvoa de Varzim', 'Quarteira', 'Queluz',
        'Rebordosa', 'Reguengos de Monsaraz', 'Ribeira Grande', 'Rio Maior',
        'Rio Tinto', 'Sabugal', 'Sacavém', 'Santa Comba Dão', 'Santa Cruz',
        'Santa Maria da Feira', 'Santana', 'Santarém', 'Santiago do Cacém',
        'Santo Tirso', 'Seia', 'Seixal', 'Serpa', 'Setúbal', 'Silves', 'Sines',
        'Sintra', 'São João da Madeira', 'São Mamede de Infesta',
        'São Salvador de Lordelo', 'Tarouca', 'Tavira', 'Tomar', 'Tondela',
        'Torres Novas', 'Torres Vedras', 'Trancoso', 'Trofa', 'Valbom',
        'Vale de Cambra', 'Valongo', 'Valpaços', 'Vendas Novas',
        'Viana do Castelo', 'Vila Franca de Xira', 'Vila Nova de Famalicão',
        'Vila Nova de Foz Côa', 'Vila Nova de Gaia', 'Vila Nova de Santo André',
        'Vila Real', 'Vila Real de Santo António', 'Vila do Conde', 'Viseu',
        'Vizela', 'Évora', 'Ílhavo',
    )

    countries = (
        'Afeganistão', 'África do Sul', 'Akrotiri', 'Albânia', 'Alemanha',
        'Andorra', 'Angola', 'Anguila', 'Antárctida', 'Antígua e Barbuda',
        'Antilhas Neerlandesas', 'Arábia Saudita', 'Arctic Ocean', 'Argélia',
        'Argentina', 'Arménia', 'Aruba', 'Ashmore and Cartier Islands',
        'Atlantic Ocean', 'Austrália', 'Áustria', 'Azerbaijão', 'Baamas',
        'Bangladeche', 'Barbados', 'Barém', 'Bélgica', 'Belize', 'Benim',
        'Bermudas', 'Bielorrússia', 'Birmânia', 'Bolívia',
        'Bósnia e Herzegovina', 'Botsuana', 'Brasil', 'Brunei', 'Bulgária',
        'Burquina Faso', 'Burúndi', 'Butão', 'Cabo Verde', 'Camarões',
        'Camboja', 'Canadá', 'Catar', 'Cazaquistão', 'Chade', 'Chile', 'China',
        'Chipre', 'Clipperton Island', 'Colômbia', 'Comores',
        'Congo-Brazzaville', 'Congo-Kinshasa', 'Coral Sea Islands',
        'Coreia do Norte', 'Coreia do Sul', 'Costa do Marfim', 'Costa Rica',
        'Croácia', 'Cuba', 'Dhekelia', 'Dinamarca', 'Domínica', 'Egipto',
        'Emiratos Árabes Unidos', 'Equador', 'Eritreia', 'Eslováquia',
        'Eslovénia', 'Espanha', 'Estados Unidos', 'Estónia', 'Etiópia', 'Faroé',
        'Fiji', 'Filipinas', 'Finlândia', 'França', 'Gabão', 'Gâmbia', 'Gana',
        'Gaza Strip', 'Geórgia', 'Geórgia do Sul e Sandwich do Sul',
        'Gibraltar', 'Granada', 'Grécia', 'Gronelândia', 'Guame', 'Guatemala',
        'Guernsey', 'Guiana', 'Guiné', 'Guiné Equatorial', 'Guiné-Bissau',
        'Haiti', 'Honduras', 'Hong Kong', 'Hungria', 'Iémen', 'Ilha Bouvet',
        'Ilha do Natal', 'Ilha Norfolk', 'Ilhas Caimão', 'Ilhas Cook',
        'Ilhas dos Cocos', 'Ilhas Falkland', 'Ilhas Heard e McDonald',
        'Ilhas Marshall', 'Ilhas Salomão', 'Ilhas Turcas e Caicos',
        'Ilhas Virgens Americanas', 'Ilhas Virgens Britânicas', 'Índia',
        'Indian Ocean', 'Indonésia', 'Irão', 'Iraque', 'Irlanda', 'Islândia',
        'Israel', 'Itália', 'Jamaica', 'Jan Mayen', 'Japão', 'Jersey', 'Jibuti',
        'Jordânia', 'Kuwait', 'Laos', 'Lesoto', 'Letónia', 'Líbano', 'Libéria',
        'Líbia', 'Listenstaine', 'Lituânia', 'Luxemburgo', 'Macau', 'Macedónia',
        'Madagáscar', 'Malásia', 'Malávi', 'Maldivas', 'Mali', 'Malta',
        'Man, Isle of', 'Marianas do Norte', 'Marrocos', 'Maurícia',
        'Mauritânia', 'Mayotte', 'México', 'Micronésia', 'Moçambique',
        'Moldávia', 'Mónaco', 'Mongólia', 'Monserrate', 'Montenegro', 'Mundo',
        'Namíbia', 'Nauru', 'Navassa Island', 'Nepal', 'Nicarágua', 'Níger',
        'Nigéria', 'Niue', 'Noruega', 'Nova Caledónia', 'Nova Zelândia', 'Omã',
        'Pacific Ocean', 'Países Baixos', 'Palau', 'Panamá', 'Papua-Nova Guiné',
        'Paquistão', 'Paracel Islands', 'Paraguai', 'Peru', 'Pitcairn',
        'Polinésia Francesa', 'Polónia', 'Porto Rico', 'Portugal', 'Quénia',
        'Quirguizistão', 'Quiribáti', 'Reino Unido',
        'República Centro-Africana', 'República Checa', 'República Dominicana',
        'Roménia', 'Ruanda', 'Rússia', 'Salvador', 'Samoa', 'Samoa Americana',
        'Santa Helena', 'Santa Lúcia', 'São Cristóvão e Neves', 'São Marinho',
        'São Pedro e Miquelon', 'São Tomé e Príncipe',
        'São Vicente e Granadinas', 'Sara Ocidental', 'Seicheles', 'Senegal',
        'Serra Leoa', 'Sérvia', 'Singapura', 'Síria', 'Somália',
        'Southern Ocean', 'Spratly Islands', 'Sri Lanca', 'Suazilândia',
        'Sudão', 'Suécia', 'Suíça', 'Suriname', 'Svalbard e Jan Mayen',
        'Tailândia', 'Taiwan', 'Tajiquistão', 'Tanzânia',
        'Território Britânico do Oceano Índico',
        'Territórios Austrais Franceses', 'Timor Leste', 'Togo', 'Tokelau',
        'Tonga', 'Trindade e Tobago', 'Tunísia', 'Turquemenistão', 'Turquia',
        'Tuvalu', 'Ucrânia', 'Uganda', 'União Europeia', 'Uruguai',
        'Usbequistão', 'Vanuatu', 'Vaticano', 'Venezuela', 'Vietname',
        'Wake Island', 'Wallis e Futuna', 'West Bank', 'Zâmbia', 'Zimbabué',
    )

    # From https://pt.wikipedia.org/wiki/Distritos_de_Portugal
    distritos = (
        'Aveiro', 'Beja', 'Braga', 'Bragança', 'Castelo Branco', 'Coimbra',
        'Évora', 'Faro', 'Guarda', 'Leiria', 'Lisboa', 'Portalegre', 'Porto',
        'Santarém', 'Setúbal', 'Viana do Castelo', 'Vila Real', 'Viseu',
    )

    # From https://pt.wikipedia.org/wiki/Lista_de_freguesias_de_Portugal
    freguesias = [
        "Abrantes", "Águeda", "Aguiar da Beira", "Alandroal",
        "Albergaria-a-Velha", "Albufeira", "Alcácer do Sal", "Alcanena",
        "Alcobaça", "Alcochete", "Alcoutim", "Alenquer", "Alfândega da Fé",
        "Alijó", "Aljezur", "Aljustrel", "Almada", "Almeida", "Almeirim",
        "Almodôvar", "Alpiarça", "Alter do Chão", "Alvaiázere", "Alvito",
        "Amadora", "Amarante", "Amares", "Anadia", "Angra do Heroísmo",
        "Ansião", "Arcos de Valdevez", "Arganil", "Armamar", "Arouca",
        "Arraiolos", "Arronches", "Arruda dos Vinhos", "Aveiro", "Avis",
        "Azambuja", "Baião", "Barcelos", "Barrancos", "Barreiro", "Batalha",
        "Beja", "Belmonte", "Benavente", "Bombarral", "Borba", "Boticas",
        "Braga", "Bragança", "Cabeceiras de Basto", "Cadaval",
        "Caldas da Rainha", "Calheta (Açores)", "Calheta (Madeira)",
        "Câmara de Lobos", "Caminha", "Campo Maior", "Cantanhede",
        "Carrazeda de Ansiães", "Carregal do Sal", "Cartaxo", "Cascais",
        "Castanheira de Pêra", "Castelo Branco", "Castelo de Paiva",
        "Castelo de Vide", "Castro Daire", "Castro Marim", "Castro Verde",
        "Celorico da Beira", "Celorico de Basto", "Chamusca", "Chaves",
        "Cinfães", "Coimbra", "Condeixa-a-Nova", "Constância", "Coruche",
        "Corvo", "Covilhã", "Crato", "Cuba", "Elvas", "Entroncamento",
        "Espinho", "Esposende", "Estarreja", "Estremoz", "Évora", "Fafe",
        "Faro", "Felgueiras", "Ferreira do Alentejo", "Ferreira do Zêzere",
        "Figueira da Foz", "Figueira de Castelo Rodrigo",
        "Figueiró dos Vinhos", "Fornos de Algodres",
        "Freixo de Espada à Cinta", "Fronteira", "Funchal", "Fundão", "Gavião",
        "Góis", "Golegã", "Gondomar", "Gouveia", "Grândola", "Guarda",
        "Guimarães", "Horta", "Idanha-a-Nova", "Ílhavo", "Lagoa",
        "Lagoa (Açores)", "Lagos", "Lajes das Flores", "Lajes do Pico",
        "Lamego", "Leiria", "Lisboa", "Loulé", "Loures", "Lourinhã", "Lousã",
        "Lousada", "Mação", "Macedo de Cavaleiros", "Machico", "Madalena",
        "Mafra", "Maia", "Mangualde", "Manteigas", "Marco de Canaveses",
        "Marinha Grande", "Marvão", "Matosinhos", "Mealhada", "Mêda",
        "Melgaço", "Mértola", "Mesão Frio", "Mira", "Miranda do Corvo",
        "Miranda do Douro", "Mirandela", "Mogadouro", "Moimenta da Beira",
        "Moita", "Monção", "Monchique", "Mondim de Basto", "Monforte",
        "Montalegre", "Montemor-o-Novo", "Montemor-o-Velho", "Montijo",
        "Mora", "Mortágua", "Moura", "Mourão", "Murça", "Murtosa", "Nazaré",
        "Nelas", "Nisa", "Nordeste", "Óbidos", "Odemira", "Odivelas",
        "Oeiras", "Oleiros", "Olhão", "Oliveira de Azeméis",
        "Oliveira de Frades", "Oliveira do Bairro", "Oliveira do Hospital",
        "Ourém", "Ourique", "Ovar", "Paços de Ferreira", "Palmela",
        "Pampilhosa da Serra", "Paredes", "Paredes de Coura", "Pedrógão Grande",
        "Penacova", "Penafiel", "Penalva do Castelo", "Penamacor", "Penedono",
        "Penela", "Peniche", "Peso da Régua", "Pinhel", "Pombal",
        "Ponta Delgada", "Ponta do Sol", "Ponte da Barca", "Ponte de Lima",
        "Ponte de Sor", "Portalegre", "Portel", "Portimão", "Porto",
        "Porto de Mós", "Porto Moniz", "Porto Santo", "Póvoa de Lanhoso",
        "Póvoa de Varzim", "Povoação", "Praia da Vitória", "Proença-a-Nova",
        "Redondo", "Reguengos de Monsaraz", "Resende", "Ribeira Brava",
        "Ribeira de Pena", "Ribeira Grande", "Rio Maior", "Sabrosa", "Sabugal",
        "Salvaterra de Magos", "Santa Comba Dão", "Santa Cruz",
        "Santa Cruz da Graciosa", "Santa Cruz das Flores",
        "Santa Maria da Feira", "Santa Marta de Penaguião", "Santana",
        "Santarém", "Santiago do Cacém", "Santo Tirso", "São Brás de Alportel",
        "São João da Madeira", "São João da Pesqueira", "São Pedro do Sul",
        "São Roque do Pico", "São Vicente (Madeira)", "Sardoal", "Sátão",
        "Seia", "Seixal", "Sernancelhe", "Serpa", "Sertã", "Sesimbra",
        "Setúbal", "Sever do Vouga", "Silves", "Sines", "Sintra",
        "Sobral de Monte Agraço", "Soure", "Sousel", "Tábua", "Tabuaço",
        "Tarouca", "Tavira", "Terras de Bouro", "Tomar", "Tondela",
        "Torre de Moncorvo", "Torres Novas", "Torres Vedras", "Trancoso",
        "Trofa", "Vagos", "Vale de Cambra", "Valença", "Valongo", "Valpaços",
        "Velas", "Vendas Novas", "Viana do Alentejo", "Viana do Castelo",
        "Vidigueira", "Vieira do Minho", "Vila de Rei", "Vila do Bispo",
        "Vila do Conde", "Vila do Porto", "Vila Flor", "Vila Franca de Xira",
        "Vila Franca do Campo", "Vila Nova da Barquinha",
        "Vila Nova de Cerveira", "Vila Nova de Famalicão",
        "Vila Nova de Foz Côa", "Vila Nova de Gaia", "Vila Nova de Paiva",
        "Vila Nova de Poiares", "Vila Pouca de Aguiar", "Vila Real",
        "Vila Real de Santo António", "Vila Velha de Ródão", "Vila Verde",
        "Vila Viçosa", "Vimioso", "Vinhais", "Viseu", "Vizela", "Vouzela",
    ]

    def street_prefix(self):
        """
        :example 'Rua'
        """
        return self.random_element(self.street_prefixes)

    def city_name(self):
        """
        :example 'Amora'
        """
        return self.random_element(self.cities)

    def distrito(self):
        """
        :example 'Bragança'
        """
        return self.random_element(self.distritos)

    def freguesia(self):
        """
        :example 'Miranda do Douro'
        """
        return self.random_element(self.freguesias)



# coding=utf-8


from __future__ import unicode_literals
from .. import Provider as AutomotiveProvider


class Provider(AutomotiveProvider):

    # https://en.wikipedia.org/wiki/Vehicle_registration_plates_of_Russia
    license_plate_letters = ('A', 'B', 'E', 'M', 'Н', 'О', 'Р', 'С', 'Т', 'У', 'Х')

    license_plate_suffix = (
        # Republic of Adygea
        '01',
        # Republic of Bashkortostan
        '02', '102',
        # Republic of Buryatia
        '03',
        # Altai Republic
        '04',
        # Republic of Dagestan
        '05',
        # Republic of Ingushetia
        '06',
        # Kabardino-Balkar Republic
        '07',
        # Republic of Kalmykia
        '08',
        # Karachay-Cherkess Republic
        '09',
        # Republic of Karelia
        '10',
        # Komi Republic
        '11',
        # Mari El Republic
        '12',
        # Republic of Mordovia
        '13', '113',
        # Sakha Republic
        '14',
        # Republic of North Ossetia–Alania
        '15',
        # Republic of Tatarstan
        '16', '116', '716',
        # Tuva Republic
        '17',
        # Udmurt Republic
        '18',
        # Republic of Khakassia
        '19',
        # Chechen Republic
        '20', '95',
        # Chuvash Republic
        '21', '121',
        # Altai Krai
        '22',
        # Krasnodar Krai
        '23', '93', '123',
        # Krasnoyarsk Krai
        '24', '84', '88', '124',
        # Primorsky Krai
        '25', '125',
        # Stavropol Krai
        '26', '126',
        # Khabarovsk Krai
        '27',
        # Amur Oblast
        '28',
        # Arkhangelsk Oblast
        '29',
        # Astrakhan Oblast
        '30',
        # Belgorod Oblast
        '31',
        # Bryansk Oblast
        '32',
        # Vladimir Oblast
        '33',
        # Volgograd Oblast
        '34', '134',
        # Vologda Oblast
        '35',
        # Voronezh Oblast
        '36', '136',
        # Ivanovo Oblast
        '37',
        # Irkutsk Oblast
        '38', '85', '38',
        # Kaliningrad Oblast
        '39', '91',
        # Kaluga Oblast
        '40',
        # Kamchatka Krai
        '41', '82',
        # Kemerovo Oblast
        '42', '142',
        # Kirov Oblast
        '43',
        # Kostroma Oblast
        '44',
        # Kurgan Oblast
        '45',
        # Kursk Oblast
        '46',
        # Leningrad Oblast
        '47',
        # Lipetsk Oblast
        '48',
        # Magadan Oblast
        '49',
        # Moscow Oblast
        '50', '90', '150', '190', '750',
        # Murmansk Oblast
        '51',
        # Nizhny Novgorod Oblast
        '52', '152',
        # Novgorod Oblast
        '53',
        # Novosibirsk Oblast
        '54', '154',
        # Omsk Oblast
        '55',
        # Orenburg Oblast
        '56',
        # Oryol Oblast
        '57',
        # Penza Oblast
        '58',
        # Perm Krai
        '59', '81', '159',
        # Pskov Oblast
        '60',
        # Rostov Oblast
        '61', '161',
        # Ryazan Oblast
        '62',
        # Samara Oblast
        '63', '163', '763',
        # Saratov Oblast
        '64', '164',
        # Sakhalin Oblast
        '65',
        # Sverdlovsk Oblast
        '66', '96', '196',
        # Smolensk Oblast
        '67',
        # Tambov Oblast
        '68',
        # Tver Oblast
        '69',
        # Tomsk Oblast
        '70',
        # Tula Oblast
        '71',
        # Tyumen Oblast
        '72',
        # Ulyanovsk Oblast
        '73', '173',
        # Chelyabinsk Oblast
        '74', '174',
        # Zabaykalsky Krai
        '75', '80',
        # Yaroslavl Oblast
        '76',
        # Moscow
        '77', '97', '99', '177', '197', '199', '777', '799',
        # St. Petersburg
        '78', '98', '178', '198',
        # Jewish Autonomous Oblast
        '79',
        # Agin-Buryat Okrug / "Former Buryat Autonomous District of Aginskoye"
        '80',
        # Komi-Permyak Okrug / "Former Komi-Permyak Autonomous District"
        '81',
        # Republic of Crimea / De jure part of Ukraine as Autonomous Republic. Annexed by Russia in 2014.
        '82',
        # Koryak Okrug / "Former Koryak Autonomous District"
        '82',
        # Nenets Autonomous Okrug (Nenetsia)
        '83',
        # Taymyr Autonomous Okrug / "Former Taymyr (Dolgan-Nenets) Autonomous District"
        '84',
        # Ust-Orda Buryat Okrug / "Former Buryat Autonomous District of Ust-Ordynskoy"
        '85',
        # Khanty-Mansi Autonomous Okrug
        '86', '186',
        # Chukotka Autonomous Okrug
        '87',
        # Evenk Autonomous Okrug / "Former Evenk Autonomous District"
        '88',
        # Yamalo-Nenets Autonomous Okrug
        '89',
        # Sevastopol / De jure part of Ukraine as City with special status. Annexed by Russia in 2014.
        '92',
        # Territories outside of the Russian Federation,
        # served by the bodies of internal affairs of the Russian Federation, such as Baikonur
        '94',
    )

    license_plate_number = (
        '##%'
    )

    def license_plate(self):
        return self.random_element(self.license_plate_letters) + \
               self.numerify(self.generator.parse(self.license_plate_number)) + \
               self.random_element(self.license_plate_letters) + \
               self.random_element(self.license_plate_letters) + \
               self.random_element(self.license_plate_suffix)



# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as BaseProvider


# Taiwan jobs from
# http://www.104.com.tw/public/function01/utf8/jsonJobCat.js
# on Fri May 20 23:13:46 CST 2016
class Provider(BaseProvider):
    jobs = [
        'BIOS工程師',
        'CAD／CAM工程師',
        'CNC機台操作人員',
        'CNC電腦程式編排人員',
        'EMC／電子安規工程師',
        'FAE工程師',
        'IC佈局工程師',
        'IC封裝／測試工程師',
        'ISO／品保人員',
        'Internet程式設計師',
        'LCD製程工程師',
        'LCD設備工程師',
        'MES工程師',
        'MIS程式設計師',
        'MIS／網管主管',
        'OP／旅行社人員',
        'PCB佈線工程師',
        'PCB技術人員',
        'RF通訊工程師',
        'SMT工程師',
        '一般動物飼育工作者',
        '不動產產權審核／估價師',
        '不動產經紀人',
        '不動產／商場開發人員',
        '中等學校教師',
        '中醫師',
        '中餐廚師',
        '主持人',
        '主管特別助理',
        '主辦會計',
        '人力資源主管',
        '人力資源人員',
        '人力資源助理',
        '人力／外勞仲介',
        '代書／地政士',
        '估算人員',
        '作曲家',
        '作業員／包裝員',
        '保全人員／警衛',
        '保全技術人員',
        '保安服務工作',
        '保稅人員',
        '保險業務／經紀人',
        '倉儲物流人員',
        '倉管',
        '催收人員',
        '傳播媒體企劃人員',
        '傳銷人員',
        '儲備幹部',
        '光學工程師',
        '光電工程師',
        '光電工程研發主管',
        '內業工程師',
        '公共衛生人員',
        '公共衛生醫師',
        '公家機關人員',
        '券商後線人員',
        '副教授',
        '加油員',
        '助教',
        '助理工程師',
        '助理教授',
        '勞工安全衛生管理人員',
        '勞工安全衛生管理師',
        '包裝設計',
        '化學工程研發人員',
        '化學研究員',
        '化工化學工程師',
        '升學補習班老師',
        '半導體工程師',
        '半導體製程工程師',
        '半導體設備工程師',
        '印前製作／印刷技術人員',
        '可靠度工程師',
        '吊車／起重機設備操作員',
        '呼吸治療師',
        '品牌宣傳及媒體公關',
        '品管／品保主管',
        '品管／品保工程師',
        '品管／檢驗人員',
        '哲學／歷史／政治研究人員',
        '售票／收銀人員',
        '商業設計',
        '商標／專利人員',
        '噴漆人員',
        '國內業務主管',
        '國內業務人員',
        '國外業務主管',
        '國外業務人員',
        '國小學校教師',
        '國貿人員',
        '圖書資料管理人員',
        '土地開發人員',
        '土木技師／土木工程師',
        '地勤人員',
        '地質與地球科學研究員',
        '塑膠射出技術人員',
        '塑膠模具技術人員',
        '塗裝技術人員',
        '壓鑄模具技術人員',
        '外務／快遞／送貨',
        '多媒體動畫設計師',
        '多媒體開發主管',
        '大樓管理員',
        '大貨車司機',
        '天文研究員',
        '太陽能技術工程師',
        '娛樂事業人員',
        '媒體公關／宣傳採買',
        '安全／衛生檢驗人員',
        '安心服務員',
        '安親班老師',
        '客戶服務主管',
        '客戶服務人員',
        '室內設計／裝潢人員',
        '家事服務人員',
        '家庭代工',
        '實驗化驗人員',
        '寵物美容專業人員',
        '專案業務主管',
        '專案管理主管',
        '專案管理師',
        '專科護理師',
        '導播',
        '導演',
        '導遊',
        '小客車司機',
        '小貨車司機',
        '居家服務督導員',
        '展場／櫥窗佈置人員',
        '工務人員／助理',
        '工商登記服務人員',
        '工地監工／主任',
        '工廠主管',
        '工業工程師／生產線規劃',
        '工業設計',
        '工程助理',
        '工程研發主管',
        '工程配管繪圖',
        '工讀生',
        '市場調查／市場分析',
        '平面設計／美編人員',
        '幼教班老師',
        '店長／賣場管理人員',
        '廠務',
        '廠務助理',
        '廣告AE業務人員',
        '廣告企劃主管',
        '廣告文案／企劃',
        '廣告設計',
        '建築師',
        '建築物清潔工',
        '建築物電力系統維修工',
        '建築設計／繪圖人員',
        '影片製作技術人員',
        '律師',
        '復建技術師',
        '微機電工程師',
        '心理學研究人員',
        '志工人員',
        '志願役軍官／士官／士兵',
        '應用科學研究員',
        '成本會計',
        '手工包裝工',
        '才藝類老師',
        '打版人員',
        '技術文件／說明書編譯',
        '按摩／推拿師',
        '排版人員',
        '採購主管',
        '採購人員',
        '採購助理',
        '推土機設備操作員',
        '播音／配音人員',
        '攝影助理',
        '攝影師',
        '放射性設備使用技術員',
        '救生員',
        '教保員',
        '教授',
        '教育訓練人員',
        '整體造型師',
        '數位IC設計工程師',
        '數學研究員',
        '數理補習班老師',
        '文件管理師',
        '文編／校對／文字工作者',
        '旅遊休閒類主管',
        '日式廚師',
        '日文翻譯／口譯人員',
        '星象占卜人員',
        '景觀設計師',
        '會計師',
        '服裝／皮包／鞋類設計',
        '木工',
        '材料研發人員',
        '板金技術員',
        '林木伐運工作者',
        '染整技術人員',
        '查帳／審計人員',
        '核保／保險內勤人員',
        '業務助理',
        '業務支援工程師',
        '樂器製造員',
        '模特兒',
        '機械加工技術人員',
        '機械工程師',
        '機械操作員',
        '機械裝配員',
        '機械設計／繪圖人員',
        '機構工程師',
        '機電技師／工程師',
        '櫃檯接待人員',
        '氣象研究員',
        '水保工程師',
        '水保技師',
        '水利工程師',
        '水產養殖工作者',
        '水電工',
        '水電工程師',
        '水電工程繪圖人員',
        '汽車美容人員',
        '汽車銷售人員',
        '汽車／機車引擎技術人員',
        '汽車／機車技術維修人員',
        '沖壓模具技術人員',
        '油漆工',
        '治療師',
        '法務人員',
        '法務助理',
        '法務／智財主管',
        '法律專業人員',
        '泥水小工',
        '泥水工',
        '洗碗人員',
        '活動企劃人員',
        '派報生／傳單派送',
        '消防員',
        '消防專業人員',
        '混凝土工',
        '清潔工',
        '測試人員',
        '演員',
        '演奏家',
        '演算法開發工程師',
        '焊接及切割技術員',
        '照顧指導員',
        '照顧服務員',
        '熱傳工程師',
        '燈光／音響師',
        '營建主管',
        '營建構造工',
        '營造工程師',
        '營運管理師',
        '營養師',
        '牙醫助理',
        '牙醫師',
        '物理治療師',
        '物理研究員',
        '物管／資材',
        '特殊工程師',
        '特殊教育教師',
        '特用化學工程師',
        '獸醫師',
        '珠寶及貴金屬技術員',
        '珠心算老師',
        '理賠人員',
        '環境工程師',
        '生命禮儀師',
        '生物學專業與研究',
        '生物科技研發人員',
        '生產技術／製程工程師',
        '生產管理主管',
        '生產設備工程師',
        '生管',
        '生管助理',
        '生鮮人員',
        '產品事業處主管',
        '產品企劃主管',
        '產品企劃開發人員',
        '產品售後技術服務',
        '產品管理師',
        '產品維修人員',
        '產品行銷人員',
        '病理藥理研究人員',
        '發包人員',
        '發行企劃／出版人員',
        '砌磚工',
        '研究人員',
        '研究助理',
        '硬體工程研發主管',
        '硬體測試工程師',
        '硬體研發工程師',
        '社工人員',
        '社會／人類學研究人員',
        '秘書',
        '稅務人員',
        '稽核人員',
        '空服員',
        '空調冷凍技術人員',
        '節目助理',
        '節目製作人員',
        '粉末冶金模具技術人員',
        '精密儀器製造工',
        '精密拋光技術人員',
        '系統整合／ERP專案師',
        '系統維護／操作人員',
        '紡織化學工程師',
        '紡織工務',
        '結構技師',
        '統計學研究員',
        '統計精算人員',
        '經營管理主管',
        '網站行銷企劃',
        '網路安全分析師',
        '網路管理工程師',
        '網頁設計師',
        '線切割技術員',
        '總務主管',
        '總務人員',
        '總幹事',
        '總機人員',
        '織品設計',
        '美姿美儀人員',
        '美容工作者',
        '美容類助理',
        '美甲彩繪師',
        '美療／芳療師',
        '美術老師',
        '美術設計',
        '美髮工作者',
        '美髮類助理',
        '翻譯／口譯人員',
        '聲學／噪音工程師',
        '聲樂家',
        '職能治療師',
        '股務人員',
        '自動控制工程師',
        '舞蹈指導與舞蹈家',
        '船務／押匯／報關人員',
        '船長／大副／船員',
        '花藝／園藝人員',
        '英文翻譯／口譯人員',
        '藝術品／珠寶鑑價／拍賣顧問',
        '藝術指導／總監',
        '藥學助理',
        '藥師',
        '融資／信用業務人員',
        '行政主管',
        '行政人員',
        '行政助理',
        '行銷企劃主管',
        '行銷企劃人員',
        '行銷企劃助理',
        '補習班導師／管理人員',
        '補習班老師',
        '製鞋類人員',
        '西餐廚師',
        '西點／蛋糕師',
        '視聽工程類人員',
        '計程車司機',
        '記帳／出納／一般會計',
        '記者／採編',
        '設計助理',
        '診所助理',
        '語文補習班老師',
        '語言治療師',
        '調酒師／吧台人員',
        '調音技術員',
        '講師',
        '護理師',
        '財務分析人員',
        '財務或會計主管',
        '財務會計助理',
        '資料庫管理人員',
        '資料輸入人員',
        '資材主管',
        '資源回收人員',
        '資訊助理人員',
        '資訊專業人員',
        '資訊設備管制人員',
        '車床人員',
        '車縫／裁縫類人員',
        '軟韌體測試工程師',
        '軟體專案主管',
        '軟體專案管理師',
        '軟體設計工程師',
        '農工業用機器裝修工',
        '農林業設備操作員',
        '農藝作物栽培工作者',
        '農藝／畜產研究人員',
        '通信測試維修人員',
        '通訊工程研發主管',
        '通訊軟體工程師',
        '通路開發人員',
        '連鎖店管理人員',
        '遊戲企劃人員',
        '運動教練',
        '運輸交通專業人員',
        '運輸物流類主管',
        '都市／交通規劃人員',
        '醫事放射師',
        '醫事檢驗師',
        '醫師',
        '醫療人員',
        '醫療器材研發工程師',
        '醫療從業人員',
        '醫療設備控制人員',
        '醫藥業務代表',
        '醫藥研發人員',
        '醫院行政管理人員',
        '量測／儀校人員',
        '金屬建材架構人員',
        '金融交易員',
        '金融專業主管',
        '金融承銷員',
        '金融營業員',
        '金融理財專員',
        '金融研究員',
        '銀行辦事員',
        '銑床人員',
        '鍋爐操作技術人員',
        '鐵路車輛駕駛員',
        '鑄造／鍛造模具技術人員',
        '門市／店員／專櫃人員',
        '防水施工人員',
        '防火及建築檢驗人員',
        '零件工程師',
        '雷射操作技術員',
        '電信及電力線路架設工',
        '電信／通訊系統工程師',
        '電台工作人員',
        '電子商務技術主管',
        '電子工程師',
        '電子產品系統工程師',
        '電子設備裝修工',
        '電機工程技術員',
        '電機技師／工程師',
        '電機裝修工',
        '電機設備裝配員',
        '電源工程師',
        '電玩程式設計師',
        '電腦系統分析師',
        '電腦組裝／測試',
        '電腦繪圖人員',
        '電腦補習班老師',
        '電話及電報機裝修工',
        '電話客服類人員',
        '電話行銷人員',
        '電鍍／表面處理技術人員',
        '韌體設計工程師',
        '音樂家',
        '音樂老師',
        '領班',
        '領隊',
        '類廚師',
        '類比IC設計工程師',
        '類講師',
        '顧問人員',
        '飛安人員',
        '飛機裝修工',
        '飛行機師',
        '食品研發人員',
        '食品衛生管理師',
        '飯店工作人員',
        '飯店餐廳主管',
        '餐廚助手',
        '餐飲服務生',
        '駐校代表',
        '驗光師',
        '麵包師',
        '麻醉醫師',
    ]



# coding=utf-8

from __future__ import unicode_literals
from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats_male = (
        '{{first_name_male}} {{last_name}}',
    )

    formats_female = (
        '{{first_name_female}} {{last_name}}',
    )

    formats = formats_male + formats_female

    # Source: https://en.wiktionary.org/wiki/Category:Armenian_male_given_names
    first_names_male = (
        'Սիմոն',
        'Ուիլյամ',
        'Ստեֆան',
        'Ռիչարդ',
        'Ֆիլիպ',
        'Ջոն',
        'Հովիկ',
        'Հենրի',
        'Ջորջ',
        'Գարրի',
        'Ֆելիքս',
        'Լևոն',
        'Դոմինիկ',
        'Դենիս',
        'Դանիել',
        'Կլոդ',
        'Քրիստոֆեր',
        'Չարլի',
        'Կարլ',
        'Բորիս',
        'Բեռնար',
        'Անդրեաս',
        'Ալեքսանդր',
        'Աբրահամ',
        'Աբել',
        'Ահարոն',
        'Օլեգ',
        'Փայլակ',
        'Ցոլակ',
        'Րաֆֆի',
        'Տարոն',
        'Վլադիմիր',
        'Վիկտոր',
        'Վահե',
        'Վախթանգ',
        'Վազգեն',
        'Ստեփան',
        'Սեյրան',
        'Սերգեյ',
        'Ռուդոլֆ',
        'Ռուբեն',
        'Ռոման',
        'Ռոբերտ',
        'Ռաֆայել',
        'Շահեն',
        'Նորայր',
        'Նշան',
        'Նարեկ',
        'Նաիրի',
        'Յուրի',
        'Մուրադ',
        'Մխիթար',
        'Մաքսիմ',
        'Մարկոս',
        'Մանվել',
        'Կարեն',
        'Էդուարդ',
        'Էդգար',
        'Զոհրաբ',
        'Գրիգոր',
        'Գոռ',
        'Գևորգ',
        'Գաբրիել',
        'Արման',
        'Արթուր',
        'Անդրանիկ',
        'Ալբերտ',
        'Ադամ',
        'Աբել',
        'Հովհաննես',
        'Աբիգ',
        'Ավետիք',
        'Ավետիս',
        'Աղասի',
        'Ազատ',
        'Հայկ',
        'Հայկազ',
        'Հակոբ',
        'Համազասպ',
        'Հմայակ',
        'Առաքել',
        'Արամ',
        'Արամազդ',
        'Արգամ',
        'Արգիշտի',
        'Արեգ',
        'Արիստակես',
        'Արմեն',
        'Արմենակ',
        'Արսեն',
        'Արտավազդ',
        'Արտակ',
        'Արտաշես',
        'Արտեմ',
        'Արտուր',
        'Արտուշ',
        'Հարություն',
        'Առուշան',
        'Արշավիր',
        'Արշակ',
        'Ատոմ',
        'Աշոտ',
        'Բաբկեն',
        'Բաղդասար',
        'Բաղիշ',
        'Բաղրամ',
        'Բագրատ',
        'Բարսեղ',
        'Բարխուդար',
        'Վահագն',
        'Վահան',
        'Վաղարշակ',
        'Վահրամ',
        'Վարուժան',
        'Վասակ',
        'Գագիկ',
        'Գալուստ',
        'Գարեգին',
        'Գառնիկ',
        'Գարսևան',
        'Գասպար',
        'Գեղամ',
        'Հրանտ',
        'Գուրգեն',
        'Դավիթ',
        'Դերենիկ',
        'Ջիվան',
        'Եղիշ',
        'Երվանդ',
        'Ժիրայր',
        'Զավեն',
        'Զորի',
        'Զոհրապ',
        'Կիկոս',
        'Կիրակոս',
        'Կորյուն',
        'Մամիկոն',
        'Մարգար',
        'Մհեր',
        'Մելքոն',
        'Մելքում',
        'Մեսրոպ',
        'Մեխակ',
        'Միհրան',
        'Մինաս',
        'Մուշեղ',
        'Ներսես',
        'Նուբար',
        'Օհան',
        'Փանոս',
        'Պարգև',
        'Պարթև',
        'Պարույր',
        'Պատվական',
        'Պետրոս',
        'Պողոս',
        'Սահակ',
        'Սաղաթել',
        'Սանասար',
        'Սարգիս',
        'Սասուն',
        'Սերոբ',
        'Սմբատ',
        'Սպարտակ',
        'Սուքիաս',
        'Սուրեն',
        'Թադևոս',
        'Թաթոս',
        'Թաթուլ',
        'Տիգրան',
        'Թորգոմ',
        'Թորոս',
        'Տրդատ',
        'Հունան',
        'Հուսիկ',
        'Խորեն',
        'Խոսրով',
        'Շավարշ',
        'Շմավոն',
    )

    # Source: https://en.wiktionary.org/wiki/Category:Armenian_female_given_names
    first_names_female = (
        'Ագապի',
        'Աիդա',
        'Ալեքսանդրա',
        'Ալինա',
        'Ալիսա',
        'Ալվարդ',
        'Ալլա',
        'Անիտա',
        'Ամալյա',
        'Անահիտ',
        'Անաստասիա',
        'Անժելա',
        'Անգելինա',
        'Անի',
        'Անյա',
        'Աննա',
        'Անտոնինա',
        'Անուշ',
        'Աստղիկ',
        'Արաքսյա',
        'Արևիկ',
        'Արմինե',
        'Արմենուհի',
        'Արփինե',
        'Բարբարա',
        'Բեթի',
        'Բելլա',
        'Բրիժիտ',
        'Բրիջիտ',
        'Գաբրիելլա',
        'Գայանե',
        'Գյուլնարա',
        'Գոհար',
        'Գրետա',
        'Դանիելլա',
        'Դիանա',
        'Դինա',
        'Ելենա',
        'Եվա',
        'Եվգինե',
        'Երանուհի',
        'Զարուհի',
        'Էլեն',
        'Էլիզա',
        'Էլինա',
        'Էմիլիա',
        'Էմմա',
        'Էրիկա',
        'Էվելինա',
        'Թագուհի',
        'Թամարա',
        'Թեհմինե',
        'Թերեզա',
        'Թինա',
        'Ժաքլին',
        'Ժաննա',
        'Իզաբելլա',
        'Ինգա',
        'Ինեսա',
        'Իննա',
        'Իրինա',
        'Լալա',
        'Լառա',
        'Լարիսա',
        'Լաուրա',
        'Լեյլա',
        'Լենա',
        'Լիա',
        'Լիանա',
        'Լիդա',
        'Լիզա',
        'Լիլիթ',
        'Լուսինե',
        'Լուիզա',
        'Ծովինար',
        'Կարինե',
        'Կարոլին',
        'Կասանդրա',
        'Կիրա',
        'Կլարա',
        'Հայկուհի',
        'Հասմիկ',
        'Հեղինե',
        'Հերմինե',
        'Հիլդա',
        'Հռիփսիմե',
        'Հրաչուհի',
        'Մագդա',
        'Մանե',
        'Մարգարիտա',
        'Մարթա',
        'Մարիամ',
        'Մարինե',
        'Մարիա',
        'Մարիաննա',
        'Մելանյա',
        'Մելինե',
        'Միլենա',
        'Մերի',
        'Մոնիկա',
        'Նազելի',
        'Նաիրա',
        'Նանա',
        'Նանե',
        'Նատաշա',
        'Նարե',
        'Նարինե',
        'Նելլի',
        'Նինա',
        'Նոննա',
        'Նորա',
        'Նվարդ',
        'Նունե',
        'Շահանե',
        'Շուշանիկ',
        'Պատրիսիա',
        'Ջեմմա',
        'Ջեյն',
        'Ջեսիկա',
        'Ջուլիետա',
        'Ռաիսա',
        'Ռեբեկա',
        'Ռիմա',
        'Ռիտա',
        'Ռուզան',
        'Սաթենիկ',
        'Սառա',
        'Սեդա',
        'Սեսիլիա',
        'Սիլվա',
        'Սիրարփի',
        'Սյուզաննա',
        'Սոնա',
        'Սոֆյա',
        'Սվետլանա',
        'Ստելլա',
        'Սուսաննա',
        'Վերոնիկա',
        'Վիկտորյա',
        'Վիոլետա',
        'Տաթևիկ',
        'Քիմ',
        'Քնարիկ',
        'Քրիստինե',
        'Օլգա',
        'Օվսաննա',
        'Օֆելյա',
        'Ֆլորա',
        'Ֆրիդա',
    )

    first_names = first_names_male + first_names_female

    # Source: https://en.wiktionary.org/wiki/Category:Armenian_surnames
    last_names = (
        'Աբազյան',
        'Աբաղյան',
        'Աբաղյանց',
        'Աբամելիքյան',
        'Աբաշյան',
        'Աբաջանյան',
        'Աբաջյան',
        'Աբասյան',
        'Աբգարյան',
        'Աբդալյան',
        'Աբդոյան',
        'Աբեթնակյան',
        'Աբելանց',
        'Աբելյան',
        'Աբեղյան',
        'Աբեշյան',
        'Աբեսալոմյանց',
        'Աբթեքյան',
        'Աբիսալոմյան',
        'Աբիսողոմոնյան',
        'Աբոյան',
        'Աբովյան',
        'Աբուջանյան',
        'Աբուսեֆյան',
        'Աբրահամյան',
        'Աբրոյան',
        'Ագիլյան',
        'Ագիշյան',
        'Ագլինցյան',
        'Ագշեհիրյան',
        'Ագոզյան',
        'Ագուլյան',
        'Ագուջյան',
        'Ագրալյան',
        'Ագրակլյան',
        'Ագրամազյան',
        'Ագրապյան',
        'Ագրիպասյան',
        'Ագրյան',
        'Ադաբաշյան',
        'Ադաթուրյան',
        'Ադալյան',
        'Ադամյան',
        'Ադամյանց',
        'Ադանալյան',
        'Ադանելյան',
        'Ադանյան',
        'Ադաջյան',
        'Ադելյան',
        'Ադեյան',
        'Ադիբեկ-Մելիքյան',
        'Ադիբեկյան',
        'Ադիգյոզալյան',
        'Ադիգոզյան',
        'Ադիլխանյան',
        'Ադիլյան',
        'Ադիխանյան',
        'Ադիմզալյան',
        'Ադիյան',
        'Ադիշյան',
        'Ադլխանյան',
        'Ադյան',
        'Ադոյան',
        'Ադոնց',
        'Ադուլյան',
        'Ադունց',
        'Ադրունի',
        'Ազաբյան',
        'Ազանյան',
        'Ազատիկյան',
        'Ազատխանյան',
        'Ազատյան',
        'Ազատյանց',
        'Ազարամյան',
        'Ազարբեկյան',
        'Ազարիկյան',
        'Ազարյան',
        'Ազարումյան',
        'Ազբեկյան',
        'Ազգալդյան',
        'Ազգալդրյան',
        'Ազգելդյան',
        'Ազգուլյան',
        'Ազդարյան',
        'Ազիզբեկյան',
        'Ազիզխանյան',
        'Ազիզյան',
        'Ազիլազյան',
        'Ազիկյան',
        'Ազիրյան',
        'Ազյան',
        'Ազնավուրյան',
        'Ազոյան',
        'Ազուլյան',
        'Ազրյան',
        'Ազրոյան',
        'Աթաբահյան',
        'Աթաբեկյան',
        'Աթաբեկյանց',
        'Աթագյուլյան',
        'Աթալարյան',
        'Աթալյան',
        'Աթալյանց',
        'Աթախանյան',
        'Աթամանյան',
        'Աթամյան',
        'Աթայան',
        'Աթանագինյան',
        'Աթանասյան',
        'Աթանեսյան',
        'Աթանոսյան',
        'Աթաշյան',
        'Աթաջյան',
        'Աթասյան',
        'Աթասունց',
        'Աթարբեկյան',
        'Աթարյան',
        'Աթաքյան',
        'Աթբաշյան',
        'Աթեճյան',
        'Աթեշյան',
        'Աթերզյան',
        'Աթինիզյան',
        'Աթինյան',
        'Աթլոյան',
        'Աթմաճյան',
        'Աթմաջյան',
        'Աթյան',
        'Աթոյան',
        'Աթոռակալյան',
        'Աթումյան',
        'Աթչյան',
        'Աթքյան',
        'Աժանջյան',
        'Աժդահարյան',
        'Աժդարյան',
        'Աժդերհանյան',
        'Աժտեհանյան',
        'Աժտերխանյան',
        'Աժտիկյան',
        'Ալաբաշյան',
        'Ալաբեկյան',
        'Ալաբերկյան',
        'Ալաբերճյան',
        'Ալագյոզյան',
        'Ալաջաջյան',
        'Ալավերդյան',
        'Ալեքսանյան',
        'Ալոյան',
        'Աղաբաբյան',
        'Աղաբեկյան',
        'Աղաջանյան',
        'Աղասյան',
        'Ամարյան',
        'Ամիրբեկյան',
        'Ամիրխանյան',
        'Այվազյան',
        'Անանյան',
        'Անդրեասյան',
        'Անղալադյան',
        'Անոփյան',
        'Անտոնյան',
        'Առաքելյան',
        'Առուստամյան',
        'Ասատրյան',
        'Ասլանյան',
        'Աստվածատրյան',
        'Ավագյան',
        'Ավդալյան',
        'Ավետիսյան',
        'Ավոյան',
        'Ավչյան',
        'Ատրյան',
        'Արեգյան',
        'Արեշյան',
        'Արզումանյան',
        'Արծրունի',
        'Բաբալյան',
        'Բաբաջանյան',
        'Բաբայան',
        'Բաբուջյան',
        'Բագրատյան',
        'Բագրատունի',
        'Բադալյան',
        'Բադալով',
        'Բադասյան',
        'Բադեյան',
        'Բադիկյան',
        'Բազեյան',
        'Բազունց',
        'Բակունց',
        'Բաղդասարյան',
        'Բարսեղյան',
        'Բեկզադյան',
        'Բեկզադով',
        'Բեկյան',
        'Բեկնազարյան',
        'Բեջանյան',
        'Բերբերյան',
        'Բոյաջյան',
        'Բոստանջյան',
        'Բունիաթյան',
        'Բուռնազյան',
        'Գաբոյան',
        'Գաբուզյան',
        'Գաբրիելյան',
        'Գալաչյան',
        'Գալստյան',
        'Գալդունց',
        'Գալֆայան',
        'Գալոյան',
        'Գասպարյան',
        'Գասպարով',
        'Գավալջյան',
        'Գարասեֆերյան',
        'Գերավետյան',
        'Գզիրյան',
        'Գիլոյան',
        'Գիմիշյան',
        'Գլեչյան',
        'Գյանջեցյան',
        'Գյուլնազարյան',
        'Գյումուշյան',
        'Գնունի',
        'Գրիգորյան',
        'Գուլաքսյան',
        'Գուլումյան',
        'Գևորգյան',
        'Դաբաղյան',
        'Դադալյան',
        'Դադասյան',
        'Դալլաքյան',
        'Դանիելյան',
        'Դարբինյան',
        'Դարչինյան',
        'Դեմուրյան',
        'Դևրիկյան',
        'Դիմաքսյան',
        'Դոդոխյան',
        'Դոլուխանյան',
        'Դոլուխանով',
        'Դոխոլյան',
        'Դոխոյան',
        'Դոխոյանց',
        'Դովլաթբեկյան',
        'Դովլաթյան',
        'Դուդուկչյան',
        'Դուզճակատչյան',
        'Դուվալյան',
        'Եգանյան',
        'Եգորյան',
        'Եղիազարյան',
        'Եղնուկյան',
        'Ենգիբարյան',
        'Ենգիբարով',
        'Ենգոյան',
        'Ենիգոմեշյան',
        'Ենոքյան',
        'Եսայան',
        'Երեմյան',
        'Երիբեկյան',
        'Երկանյան',
        'Եփրեմյան',
        'Զադոյան',
        'Զազյան',
        'Զանազանյան',
        'Զավրիյան',
        'Զավարյան',
        'Զատիկյան',
        'Զարգարյան',
        'Զարյան',
        'Զարուբյան',
        'Զաքարյան',
        'Զաքյան',
        'Զաքոյան',
        'Զելվեյան',
        'Զեյթունցյան',
        'Զեյնալյան',
        'Զոհրաբյան',
        'Զոլյան',
        'Զուռնաչյան',
        'Զուրաբյան',
        'Էլբակյան',
        'Էլոյան',
        'Էլչիբեկյան',
        'Էնֆիաջյան',
        'Էսկիբաշյան',
        'Ըրղաթբաշյան',
        'Թադևոսյան',
        'Թաթուլյան',
        'Թաթունց',
        'Թամազյան',
        'Թաշչյան',
        'Թարաքաջյան',
        'Թառայան',
        'Թերզյան',
        'Թեքեյան',
        'Թովմասյան',
        'Թորգոմյան',
        'Թորոսյան',
        'Թովուլջյան',
        'Թումանյան',
        'Թևոսյան',
        'Ժամագործյան',
        'Ժամկոչյան',
        'Իբրահիմբեկյան',
        'Իգիթբաշյան',
        'Իգիթխանյան',
        'Իգիթյան',
        'Իզմիրյան',
        'Իմաստունյան',
        'Իմեքչյան',
        'Իշլեմեճյան',
        'Իշխանյան',
        'Իշտոյան',
        'Իսաբեկյան',
        'Իսաբեկյանց',
        'Իսահակյան',
        'Իսկանդարյան',
        'Իսրայելյան',
        'Լազարյան',
        'Լազարյանց',
        'Լալայան',
        'Լալայանց',
        'Լամբարյան',
        'Լեմենցյան',
        'Լիպարիտյան',
        'Լպուտյան',
        'Լցկարյան',
        'Լուսպարոնյան',
        'Խազաբաշյան',
        'Խազխազյան',
        'Խալաֆյան',
        'Խալիկյան',
        'Խանբաբյան',
        'Խանզադյան',
        'Խաշմանյան',
        'Խաչատրյան',
        'Խաչատրյանց',
        'Խաչենց',
        'Խաչիկօղլյան',
        'Խառատյան',
        'Խեչանյան',
        'Խզմալյան',
        'Խլղաթյան',
        'Խնկոյան',
        'Խոդիկյան',
        'Խուդոյան',
        'Ծաղիկյան',
        'Ծառուկյան',
        'Ծատուրյան',
        'Ծերունյան',
        'Ծորմոտյան',
        'Ծպնեցյան',
        'Ծուռվիզյան',
        'Կաբակուլակյան',
        'Կաբաղյան',
        'Կաբասկալյան',
        'Կադարջյան',
        'Կալդրիկյան',
        'Կալենց',
        'Կալպակչյան',
        'Կամսարյան',
        'Կամսարյանց',
        'Կայֆեջյան',
        'Կաշեգործյան',
        'Կարագյան',
        'Կարախանյան',
        'Կարամանուկյան',
        'Կարապետյան',
        'Կարճիկյան',
        'Կետիկյան',
        'Կոթողյան',
        'Կոնդախչյան',
        'Կոշկակարյան',
        'Կոստանյան',
        'Կրպեյան',
        'Կույումջանյան',
        'Հալաբյան',
        'Հախվերդյան',
        'Հակոբյան',
        'Համբարձումյան',
        'Հայրապետյան',
        'Հայրբաբամյան',
        'Հայրիկյան',
        'Հատիկյան',
        'Հաջինյան',
        'Հարությունյան',
        'Հովասափյան',
        'Հովհաննիսյան',
        'Հովիվյան',
        'Հովսեփյան',
        'Հովսեփով',
        'Հուրդաջյան',
        'Ձավարյան',
        'Ձիթողցյան',
        'Ձիլֆուղարյան',
        'Ձկնորսյան',
        'Ձվակերյան',
        'Ղաբզիմալյան',
        'Ղազախեթյան',
        'Ղազանչյան',
        'Ղազարյան',
        'Ղազարով',
        'Ղազինյան',
        'Ղալդունց',
        'Ղալթախչյան',
        'Ղահրամանյան',
        'Ղամբարյան',
        'Ղայլունջյան',
        'Ղայֆեճյան',
        'Ղանդիլյան',
        'Ղասաբյան',
        'Ղասաբօղլյան',
        'Ղափլանյան',
        'Ղոլթաղչյան',
        'Ճալտիկյան',
        'Ճաղարյան',
        'Ճանճապանյան',
        'Ճանսուզյան',
        'Ճապաղջուրյան',
        'Ճգնավորյան',
        'Ճենեպերեքյան',
        'Ճիվասզյան',
        'Ճոճկանյան',
        'Ճուղուրյան',
        'Մադաթյան',
        'Մազմանյան',
        'Մանանդյան',
        'Մանուկյան',
        'Մանվելյան',
        'Մարաշյան',
        'Մարգարյան',
        'Մելիք-Աբրահամյան',
        'Մելիք-Ադամյան',
        'Մելիք-Ասլանյան',
        'Մելիք-Բարխուդարյան',
        'Մելիք-Օհանջանյան',
        'Մեհրաբյան',
        'Միկոյան',
        'Մինասբեկյան',
        'Մինասյան',
        'Միսակյան',
        'Միրզոյան',
        'Միրզոյանց',
        'Միքայելյան',
        'Մխիթարյան',
        'Մնացականյան',
        'Մշեցյան',
        'Մովսիսյան',
        'Մոսինյան',
        'Մսագործյան',
        'Մսրյան',
        'Մուշեղյան',
        'Մուշկամբարյան',
        'Մուսայելյան',
        'Մուրադյան',
        'Յաբլուկյան',
        'Յագուբյան',
        'Յազիչյան',
        'Յաղլիճյան',
        'Յոգուրթչյան',
        'Յուզբաշյան',
        'Յություճյան',
        'Նաբաթյան',
        'Նազարյան',
        'Նալբանդյան',
        'Նալչադյան',
        'Նախշքարյան',
        'Նահապետյան',
        'Ներկարարյան',
        'Ներսեսյան',
        'Ներսիսյան',
        'Նիկողոսյան',
        'Նշանյան',
        'Շաբոյան',
        'Շաբունց',
        'Շագոյան',
        'Շալավասյան',
        'Շահազիզյան',
        'Շահբազյան',
        'Շահինյան',
        'Շահինյանց',
        'Շահնազարյան',
        'Շարաբխանյան',
        'Շաքարյան',
        'Շաքրամանյան',
        'Շելունց',
        'Շուքուրյան',
        'Ոսկանյան',
        'Ոսկերչյան',
        'Չալիկյան',
        'Չալխիֆալակյան',
        'Չալոյան',
        'Չախմախչյան',
        'Չեմեդիկյան',
        'Չեպչյան',
        'Չեքիջյան',
        'Չիբուխչյան',
        'Չիլինգարյան',
        'Չիվչյան',
        'Չոբանյան',
        'Պալյան',
        'Պապայան',
        'Պապիկյան',
        'Պապոյան',
        'Պառավյան',
        'Պարոնիկյան',
        'Պարոնյան',
        'Պարոնյանց',
        'Պարսամյան',
        'Պերեճիկլյան',
        'Պետրոսյան',
        'Պետրոսյանց',
        'Պոզապալյան',
        'Պողոսյան',
        'Պողպատյան',
        'Պռոշյան',
        'Պստիկյան',
        'Ջալալբեկյան',
        'Ջանավարյան',
        'Ջանգիրյան',
        'Ջանիբեկյան',
        'Ջանջուղազյան',
        'Ջանփոլադյան',
        'Ջանունց',
        'Ջերեջյան',
        'Ջիգարխանյան',
        'Ջուլֆիղարյան',
        'Ռաշիդյան',
        'Ռասիմոսյան',
        'Ռևազյան',
        'Ռշտունի',
        'Ռոստոմյան',
        'Ռուբինյան',
        'Ռուստամյան',
        'Ռուստամյանց',
        'Սադոյան',
        'Սաթյան',
        'Սալբաշյան',
        'Սահակյան',
        'Սանթրոսյան',
        'Սանոյան',
        'Սարգսյան',
        'Սարխոյան',
        'Սարոյան',
        'Սիսոյան',
        'Սաֆարյան',
        'Սեմերջյան',
        'Սիմոնյան',
        'Սիրունյան',
        'Սոլախյան',
        'Սողոմոնյան',
        'Ստեփանյան',
        'Սրմաքեշյան',
        'Սուրմելյան',
        'Սուփրիկյան',
        'Սուքիասյան',
        'Վազիգեղցյան',
        'Վահանյան',
        'Վահունի',
        'Վանեցյան',
        'Վանյան',
        'Վարդապետյան',
        'Վարդերեսյան',
        'Վարոսյան',
        'Վարպետյան',
        'Վերանյան',
        'Վրացյան',
        'Տաճատյան',
        'Տասնապետյան',
        'Տարոնցյան',
        'Տեր-Գևորգյան',
        'Տեր-Հովհաննիսյան',
        'Տեր-Ղազարյան',
        'Տեր-Վահանյան',
        'Տոնոյան',
        'Տոպաջիկյան',
        'Տուղրեմաճյան',
        'Ցախկլորյան',
        'Ցիպլեցյան',
        'Ցոլակյան',
        'Ցրտատարյան',
        'Ուզանկիչյան',
        'Ուզունյան',
        'Ութմազյան',
        'Ուլիխանյան',
        'Ուլուբաբյան',
        'Ուստաբաշյան',
        'Ուրֆալյան',
        'Փալանդուզյան',
        'Փախչանյան',
        'Փահլևանյան',
        'Փամբուխչյան',
        'Փամբուկչյան',
        'Փայլաբազյան',
        'Փանոսյան',
        'Փաշայան',
        'Փաշինյան',
        'Փարաջանյան',
        'Փարաքեսիկյան',
        'Փարսադանյան',
        'Փափազյան',
        'Փիլիփոսյան',
        'Փոքրիկյան',
        'Քաթանասյան',
        'Քալանթարյան',
        'Քալաշյան',
        'Քաղցրիկյան',
        'Քարտաշյան',
        'Քափանակցյան',
        'Քեշիշյան',
        'Քեչօղլյան',
        'Քիլարջյան',
        'Քյոսայան',
        'Քոչարյան',
        'Քոչինյան',
        'Քրմոյան',
        'Քրքորյան',
        'Քուշքյան',
        'Օդյան',
        'Օզանյան',
        'Օզնեցյան',
        'Օհանյան',
        'Օրբելյան',
        'Ֆալյան',
        'Ֆահրադյան',
        'Ֆոլյան',
        'Ֆռանգյան',
        'Ֆրանգուլյան',
    )



# coding=utf-8
from .. import BaseProvider
import string
from string import ascii_uppercase
import re

localized = True
default_locale = 'en_GB'


class Provider(BaseProvider):
    """
    Provider for IBAN/BBAN: it generates valid (valid length, valid checksum)
    IBAN/BBANs for the given country. But the ids of the banks are random and
    not valid banks! Same for account numbers.
    """

    ALPHA = {c: str(ord(c) % 55) for c in string.ascii_uppercase}

    # see https://en.wikipedia.org/wiki/International_Bank_Account_Number
    bban_format = '????#############'
    country_code = 'GB'

    def bank_country(self):
        return self.country_code

    def bban(self):
        temp = re.sub(r'\?',
                      lambda x: self.random_element(ascii_uppercase),
                      self.bban_format)
        return self.numerify(temp)

    def iban(self):
        bban = self.bban()

        check = bban + self.country_code + '00'
        check = int(''.join(self.ALPHA.get(c, c) for c in check))
        check = 98 - (check % 97)
        check = str(check).zfill(2)

        return self.country_code + check + bban



# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as InternetProvider


class Provider(InternetProvider):

    free_email_domains = (
        'gmail.com', 'hotmail.com', 'yahoo.com',
        'net.hr', 'zg.t-com.hr', 'inet.hr', 't.ht.hr', 'vip.hr',
        'globalnet.hr', 'xnet.hr', 'yahoo.hr', 'zagreb.hr',
    )

    tlds = ('hr', 'com', 'com.hr', 'info', 'org', 'net', 'biz')

    replacements = (
        ('č', 'c'), ('Č', 'C'),
        ('ć', 'c'), ('Ć', 'C'),
        ('đ', 'dj'), ('Đ', 'Dj'),
        ('š', 's'), ('Š', 'S'),
        ('ž', 'z'), ('Ž', 'Z'),
    )



# coding=utf-8

from __future__ import unicode_literals

import re
import random as random_module

_re_token = re.compile(r'\{\{(\s?)(\w+)(\s?)\}\}')
random = random_module.Random()
mod_random = random  # compat with name released in 0.8


class Generator(object):

    __config = {}

    def __init__(self, **config):
        self.providers = []
        self.__config = dict(
            list(self.__config.items()) + list(config.items()))
        self.__random = random

    def add_provider(self, provider):

        if isinstance(provider, type):
            provider = provider(self)

        self.providers.insert(0, provider)

        for method_name in dir(provider):
            # skip 'private' method
            if method_name.startswith('_'):
                continue

            faker_function = getattr(provider, method_name)

            if callable(faker_function):
                # add all faker method to generator
                self.set_formatter(method_name, faker_function)

    def provider(self, name):
        try:
            lst = [p for p in self.get_providers()
                   if p.__provider__ == name.lower()]
            return lst[0]
        except IndexError:
            return None

    def get_providers(self):
        """Returns added providers."""
        return self.providers

    @property
    def random(self):
        return self.__random

    @random.setter
    def random(self, value):
        self.__random = value

    def seed_instance(self, seed=None):
        """Calls random.seed"""
        if self.__random == random:
            # create per-instance random obj when first time seed_instance() is
            # called
            self.__random = random_module.Random()
        self.__random.seed(seed)
        return self

    @classmethod
    def seed(cls, seed=None):
        random.seed(seed)

    def format(self, formatter, *args, **kwargs):
        """
        This is a secure way to make a fake from another Provider.
        """
        # TODO: data export?
        return self.get_formatter(formatter)(*args, **kwargs)

    def get_formatter(self, formatter):
        try:
            return getattr(self, formatter)
        except AttributeError:
            if 'locale' in self.__config:
                msg = 'Unknown formatter "{0}" with locale "{1}"'.format(
                    formatter, self.__config['locale'],
                )
            else:
                raise AttributeError('Unknown formatter "{0}"'.format(
                    formatter,
                ))
            raise AttributeError(msg)

    def set_formatter(self, name, method):
        """
        This method adds a provider method to generator.
        Override this method to add some decoration or logging stuff.
        """
        setattr(self, name, method)

    def parse(self, text):
        """
        Replaces tokens (like '{{ tokenName }}' or '{{tokenName}}')
        with the result from the token method call.
        """
        return _re_token.sub(self.__format_token, text)

    def __format_token(self, matches):
        formatter = list(matches.groups())
        formatter[1] = self.format(formatter[1])
        return ''.join(formatter)



# coding=utf-8

from faker.providers import BaseProvider


class Provider(BaseProvider):

    safe_colors = (
        'fekete', 'bordó', 'zöld', 'királykék', 'oliva',
        'bíbor', 'kékeszöld', 'citromzöld', 'kék', 'ezüst',
        'szürke', 'sárga', 'mályva', 'akvamarin', 'fehér',
    )



# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as LoremProvider


class Provider(LoremProvider):
    word_connector = ''
    word_list = (
        u'一个',
        u'我们',
        u'时间',
        u'中国',
        u'可以',
        u'公司',
        u'没有',
        u'信息',
        u'下载',
        u'软件',
        u'注册',
        u'自己',
        u'产品',
        u'工作',
        u'论坛',
        u'企业',
        u'这个',
        u'他们',
        u'管理',
        u'已经',
        u'问题',
        u'内容',
        u'使用',
        u'进行',
        u'市场',
        u'服务',
        u'如果',
        u'系统',
        u'技术',
        u'发展',
        u'现在',
        u'作者',
        u'就是',
        u'网络',
        u'提供',
        u'相关',
        u'我的',
        u'文章',
        u'方式',
        u'电话',
        u'发表',
        u'所有',
        u'时候',
        u'因为',
        u'北京',
        u'有限',
        u'公司',
        u'什么',
        u'还是',
        u'开始',
        u'本站',
        u'发布',
        u'自己',
        u'支持',
        u'在线',
        u'国家',
        u'生活',
        u'联系',
        u'积分',
        u'主题',
        u'所以',
        u'不能',
        u'的人',
        u'上海',
        u'中心',
        u'世界',
        u'游戏',
        u'需要',
        u'价格',
        u'用户',
        u'通过',
        u'要求',
        u'不是',
        u'免费',
        u'个人',
        u'但是',
        u'地址',
        u'网站',
        u'情况',
        u'最后',
        u'设计',
        u'同时',
        u'这些',
        u'活动',
        u'手机',
        u'推荐',
        u'一些',
        u'主要',
        u'大家',
        u'发现',
        u'目前',
        u'文件',
        u'你的',
        u'不过',
        u'评论',
        u'生产',
        u'美国',
        u'图片',
        u'经济',
        u'功能',
        u'国际',
        u'的是',
        u'选择',
        u'其他',
        u'这样',
        u'会员',
        u'环境',
        u'来自',
        u'日期',
        u'成为',
        u'他的',
        u'最新',
        u'专业',
        u'一下',
        u'人员',
        u'任何',
        u'教育',
        u'资料',
        u'状态',
        u'都是',
        u'点击',
        u'为了',
        u'不会',
        u'出现',
        u'知道',
        u'社会',
        u'名称',
        u'而且',
        u'介绍',
        u'音乐',
        u'等级',
        u'可能',
        u'这种',
        u'建设',
        u'朋友',
        u'虽然',
        u'电子',
        u'资源',
        u'看到',
        u'精华',
        u'电影',
        u'如何',
        u'新闻',
        u'阅读',
        u'安全',
        u'全国',
        u'只有',
        u'回复',
        u'大学',
        u'学生',
        u'学习',
        u'关于',
        u'项目',
        u'不同',
        u'以及',
        u'有关',
        u'那么',
        u'开发',
        u'还有',
        u'只是',
        u'非常',
        u'研究',
        u'广告',
        u'首页',
        u'方法',
        u'希望',
        u'地方',
        u'也是',
        u'单位',
        u'怎么',
        u'应该',
        u'今天',
        u'以上',
        u'更新',
        u'帖子',
        u'显示',
        u'能力',
        u'电脑',
        u'记者',
        u'查看',
        u'位置',
        u'不要',
        u'由于',
        u'无法',
        u'详细',
        u'投资',
        u'是一',
        u'一般',
        u'进入',
        u'发生',
        u'这里',
        u'感觉',
        u'更多',
        u'你们',
        u'的话',
        u'起来',
        u'标准',
        u'一样',
        u'认为',
        u'女人',
        u'那个',
        u'设备',
        u'搜索',
        u'之后',
        u'然后',
        u'学校',
        u'销售',
        u'组织',
        u'说明',
        u'提高',
        u'为什',
        u'作品',
        u'或者',
        u'喜欢',
        u'东西',
        u'方面',
        u'简介',
        u'必须',
        u'经营',
        u'科技',
        u'作为',
        u'其中',
        u'运行',
        u'工程',
        u'解决',
        u'操作',
        u'经验',
        u'地区',
        u'重要',
        u'直接',
        u'登录',
        u'合作',
        u'结果',
        u'影响',
        u'这是',
        u'行业',
        u'对于',
        u'表示',
        u'程序',
        u'包括',
        u'留言',
        u'规定',
        u'处理',
        u'男人',
        u'各种',
        u'部门',
        u'数据',
        u'具有',
        u'商品',
        u'系列',
        u'大小',
        u'因此',
        u'关系',
        u'可是',
        u'比较',
        u'文化',
        u'一直',
        u'法律',
        u'这么',
        u'您的',
        u'城市',
        u'分析',
        u'基本',
        u'最大',
        u'类别',
        u'两个',
        u'日本',
        u'得到',
        u'一次',
        u'继续',
        u'成功',
        u'她的',
        u'责任',
        u'深圳',
        u'业务',
        u'欢迎',
        u'加入',
        u'能够',
        u'觉得',
        u'部分',
        u'中文',
        u'根据',
        u'人民',
        u'政府',
        u'控制',
        u'其实',
        u'之间',
        u'一种',
        u'威望',
        u'实现',
        u'语言',
        u'出来',
        u'谢谢',
        u'社区',
        u'品牌',
        u'是否',
        u'工具',
        u'完全',
        u'决定',
        u'很多',
        u'网上',
        u'事情',
        u'今年',
        u'国内',
        u'以后',
        u'制作',
        u'浏览',
        u'过程',
        u'完成',
        u'类型',
        u'来源',
        u'质量',
        u'有些',
        u'一起',
        u'当然',
        u'汽车',
        u'一点',
        u'帮助',
        u'增加',
        u'历史',
        u'以下',
        u'不断',
        u'应用',
        u'那些',
        u'密码',
        u'计划',
        u'如此',
        u'次数',
        u'到了',
        u'拥有',
        u'孩子',
        u'原因',
        u'参加',
        u'只要',
        u'报告',
        u'当前',
        u'客户',
        u'正在',
        u'注意',
        u'标题',
        u'空间',
        u'一定',
        u'一切',
        u'特别',
        u'全部',
        u'准备',
    )



# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats = ['{{first_name}} {{last_name}}']

    first_names_male = [
        "Aldo", "Alen", "Andrija", "Ante", "Anto", "Anton", "Antonio",
        "Antun", "Boris", "Božo", "Branko", "Bruno", "Dalibor", "Damir",
        "Danijel", "Dario", "Darko", "David", "Davor", "Dejan", "Denis",
        "Dino", "Domagoj", "Dominik", "Dragan", "Dragutin", "Dražen",
        "Duje", "Dušan", "Elvis", "Erik", "Filip", "Fran", "Franjo",
        "Goran", "Hrvoje", "Igor", "Ilija", "Ivan", "Ivica", "Ivo",
        "Jakov", "Janko", "Josip", "Joso", "Jozo", "Joško", "Juraj",
        "Jure", "Karlo", "Kristijan", "Leon", "Lovre", "Lovro", "Luka",
        "Marijan", "Marin", "Mario", "Marko", "Martin", "Mate", "Matej",
        "Mateo", "Matija", "Mato", "Mihael", "Mijo", "Milan", "Mile",
        "Mirko", "Miroslav", "Mislav", "Mladen", "Nenad", "Niko",
        "Nikola", "Nikša", "Patrik", "Pavao", "Pero", "Petar", "Robert",
        "Roko", "Romano", "Rudolf", "Saša", "Siniša", "Slavko", "Stjepan",
        "Tomislav", "Tomo", "Toni", "Valter", "Vedran", "Viktor",
        "Vjekoslav", "Vladimir", "Vlado", "Zdravko", "Zlatko", "Zoran",
        "Zvonko", "Đuro", "Šime", "Željko",
    ]

    first_names_female = [
        "Albina", "Ana", "Andrea", "Ane", "Anica", "Anita", "Anka",
        "Ankica", "Antonija", "Anđa", "Anđela", "Bara", "Barbara",
        "Barica", "Biljana", "Biserka", "Božena", "Božica", "Branka",
        "Danica", "Danijela", "Dora", "Draga", "Dragica", "Elizabeta",
        "Ema", "Eva", "Franciska", "Fuma", "Gordana", "Hana", "Ika",
        "Iva", "Ivana", "Ivanka", "Ivka", "Jadranka", "Jana", "Janja",
        "Jasminka", "Jasna", "Jele", "Jelena", "Josipa", "Julijana",
        "Karla", "Kata", "Katarina", "Kate", "Katica", "Kristina", "Lana",
        "Lara", "Laura", "Lea", "Lidija", "Ljiljana", "Ljubica", "Lorena",
        "Lucija", "Maja", "Manda", "Mara", "Mare", "Maria", "Marica",
        "Marija", "Marijana", "Marina", "Marta", "Martina", "Matea",
        "Mateja", "Matija", "Mia", "Milena", "Milica", "Milka", "Mira",
        "Mirjana", "Nada", "Nataša", "Nevenka", "Nika", "Nikolina",
        "Nina", "Petra", "Renata", "Rozalija", "Ruža", "Ružica",
        "Sandra", "Sanja", "Sara", "Slavica", "Snježana", "Stana",
        "Suzana", "Tatjana", "Tea", "Terezija", "Valentina", "Vera",
        "Veronika", "Vesna", "Zdenka", "Zora", "Zorka", "Đurđica",
        "Štefanija", "Štefica", "Željka",
    ]

    first_names = first_names_female + first_names_male
    last_names = [
        "Abičić", "Abramović", "Adžijević", "Akmačić", "Alković",
        "Amanović", "Amidžić", "Andrašek", "Andrijašević", "Andrijević",
        "Aničić", "Antić", "Antolković", "Antonić", "Babić", "Bajan",
        "Baksa", "Balatinac", "Balinčić", "Balić", "Baljak", "Ban",
        "Baničević", "Banko", "Banovac", "Barac", "Barać", "Barbieri",
        "Barbir", "Barbić", "Barešić", "Barić", "Baričević", "Barišić",
        "Barković", "Barnaba", "Barušić", "Batrac", "Batrnek", "Bazjak",
        "Bačak", "Bačić", "Bašić", "Bašnec", "Bebić", "Begonja", "Beletić",
        "Belošević", "Benić", "Benčić", "Beraković", "Bernardić", "Bertoša",
        "Bezić", "Bijelić", "Bingula", "Birkić", "Birtić", "Bićanić",
        "Bičak", "Bičanić", "Bjeliš", "Blagaić", "Blažek", "Blažević",
        "Blažičko", "Boban", "Bobanović", "Bogadi", "Bogdan", "Bogović",
        "Bojanić", "Boljkovac", "Bolčević", "Borak", "Borojević", "Borošak",
        "Bosilj", "Botica", "Botić", "Bošnjak", "Bošnjaković", "Božanić",
        "Božanović", "Božiković", "Božić", "Božičević", "Božičković",
        "Bradić", "Brajković", "Bralić", "Brandić", "Branković", "Bračun",
        "Brcko", "Brezjan", "Britvec", "Brlas", "Brlek", "Brletić", "Bukvić",
        "Buljan", "Bungić", "Bunić", "Bunčić", "Burić", "Burčul", "Buršić",
        "Butković", "Buzov", "Bučanac", "Bučar", "Bušljeta", "Cafuk", "Car",
        "Carić", "Cestarić", "Ciganović", "Cik", "Cindrić", "Colić", "Crevar",
        "Crneković", "Crnković", "Cukon", "Culi", "Cvenić", "Cvetković",
        "Cvetnić", "Cvitan", "Cvrtila", "Dabo", "Damijanić", "Damjanović",
        "Darojković", "Dautanec", "Dautović", "Debelić", "Derežić", "Deže",
        "Didović", "Dizdar", "Dobrić", "Dolinar", "Dolić", "Dominiković",
        "Dominković", "Dončević", "Dragičević", "Dragobratović", "Dragojević",
        "Drakulić", "Drandić", "Dražić", "Dretvić", "Dubovečak", "Dujmović",
        "Dukić", "Duvančić", "Dvojak", "Džapo", "Erceg", "Ercegović",
        "Ergotić", "Eršek", "Eterović", "Fabijanić", "Ferenac", "Filar",
        "Filipović", "Filipčić", "Flego", "Forjan", "Franić", "Franičević",
        "Franjić", "Franušić", "Friščić", "Frketić", "Fuček", "Gabud",
        "Galešić", "Galić", "Galović", "Gegić", "Gelemanović", "Glasnović",
        "Glavan", "Glavor", "Gligora", "Godinić", "Golubić", "Gotić",
        "Govorčinović", "Gracin", "Grba", "Grbac", "Gredičak", "Gregov",
        "Grgić", "Grgurević", "Grgurić", "Grgurovac", "Grubišić", "Gržetić",
        "Gržinčić", "Guberović", "Gudelj", "Gulan", "Guštin", "Hadrović",
        "Hadžić", "Halambek", "Halapir", "Hanžek", "Harapin", "Hardi",
        "Herceg", "Herout", "Hećimović", "Hinić", "Hodak", "Horak", "Horvat",
        "Horvatek", "Horvatinec", "Horvatić", "Hrabar", "Hranić", "Hranj",
        "Hrastinski", "Hren", "Hrvojić", "Hršak", "Hrženjak", "Huljev",
        "Husnjak", "Ignac", "Ilijić", "Ilinović", "Ilić", "Ivandić",
        "Ivanović", "Ivančan", "Ivšić", "Jagarinec", "Jagečić", "Jakopec",
        "Jakopović", "Jakovac", "Jaković", "Jakovljević", "Jakupić", "Jakuš",
        "Jasprica", "Jelavić", "Jelić", "Jemrić", "Jerković", "Jonjić",
        "Josipović", "Jovanovac", "Jovanović", "Jović", "Jozić", "Jugovac",
        "Jukić", "Juretić", "Jureško", "Jurić", "Jurišić", "Jurjević",
        "Jurković", "Jurlina", "Jurčić", "Kadija", "Kahlina", "Kalanjoš",
        "Kalazić", "Kaniški", "Karagić", "Karamarko", "Karlović", "Karmelić",
        "Karuza", "Katić", "Kauzlarić", "Keleković", "Kelečić", "Kelić",
        "Kereković", "Kevo", "Kinkela", "Kirinčić", "Klanac", "Klarin",
        "Klarić", "Klasić", "Kligl", "Knezović", "Knežević", "Kocijančić",
        "Kokanović", "Kokorić", "Kolarec", "Kolega", "Kolić", "Komar",
        "Komljenović", "Kopjar", "Kos", "Kosanović", "Kosić", "Kostanić",
        "Kostelac", "Kovač", "Kovaček", "Kovačević", "Kovačić", "Koški",
        "Koščević", "Krajcar", "Kralj", "Kraljević", "Kraljić", "Kramarić",
        "Kresonja", "Križan", "Krpan", "Krznarić", "Krčelić", "Kršanac",
        "Krželj", "Kujundžić", "Kukučka", "Kunac", "Kupsjak", "Kurtoić",
        "Kuveždić", "Kuzmić", "Kučić", "Kuščević", "Labaš", "Labinjan",
        "Ladavac", "Lakošeljac", "Lasić", "Lazar", "Legović", "Lelas",
        "Lenić", "Lešić", "Lešković", "Leščić", "Liber", "Licul", "Liović",
        "Lisica", "Ljubetić", "Ljubić", "Ljubičić", "Lojen", "Lorencin",
        "Lovrić", "Lucić", "Lukinić", "Lukić", "Lukša", "Lukšić", "Lučić",
        "Macan", "Madunić", "Magić", "Mahnet", "Majdenić", "Majstorović",
        "Makovac", "Maletić", "Malnar", "Maloča", "Mamić", "Mamula", "Maras",
        "Marasović", "Maraš", "Mardešić", "Maretić", "Marijanović", "Marin",
        "Marinković", "Marinović", "Marić", "Maričević", "Marjanović",
        "Markanjević", "Markovac", "Marković", "Markuš", "Martinić",
        "Martinović", "Martinčević", "Martić", "Marušić", "Maršić", "Maržić",
        "Matahlija", "Matana", "Matas", "Mateša", "Matijaš", "Matijević",
        "Matić", "Matko", "Matković", "Matokanović", "Matovina", "Matošević",
        "Matulin", "Matulić", "Mavra", "Maćešić", "Medač", "Medić", "Medved",
        "Meić", "Merkaš", "Mesarić", "Mesić", "Mihalić", "Mihaljević",
        "Mihelčić", "Mihić", "Mikić", "Miklečić", "Mikulandra", "Mikulec",
        "Mikulčić", "Milas", "Milatić", "Miletić", "Milevoj", "Milina",
        "Miličić", "Miloslavić", "Milotić", "Milovac", "Mimica", "Miočić",
        "Mirosavljević", "Mirt", "Mičetić", "Mišak", "Miše", "Mišković",
        "Modrić", "Mofardin", "Morić", "Moscarda", "Moslavac", "Močibob",
        "Mraović", "Mudri", "Mudronja", "Mustapić", "Mustač", "Mušćet",
        "Mužina", "Mužić", "Nakić", "Načinović", "Nedić", "Nikolić", "Nimac",
        "Nišević", "Nižetić", "Norac", "Novak", "Novosel", "Obradović",
        "Obratov", "Odobašić", "Orbanić", "Orešković", "Orlić", "Orlović",
        "Oršolić", "Oršoš", "Oršulić", "Ozimec", "Pajur", "Palić", "Pamić",
        "Pandurić", "Papak", "Paparić", "Paradi", "Pavelić", "Pavin", "Pavić",
        "Pavičić", "Pavković", "Pavlović", "Pecotić", "Pedišić", "Peharda",
        "Penić", "Perak", "Perić", "Perišić", "Perkov", "Perković", "Peroš",
        "Peruško", "Perčić", "Petek", "Peterlik", "Petrić", "Petričević",
        "Petrović", "Pečur", "Peša", "Pešić", "Pikec", "Piljek", "Pintarić",
        "Plantak", "Plantek", "Plažanin", "Pleše", "Pokas", "Pokos", "Polić",
        "Poljak", "Polonijo", "Polović", "Pongrac", "Popović", "Poropat",
        "Poslon", "Pozder", "Požega", "Predovan", "Prelec", "Preočanin",
        "Pribanić", "Priselac", "Prpić", "Prskalo", "Prtenjača", "Puharić",
        "Puljiz", "Putinja", "Puškarić", "Radelić", "Radin", "Radinović",
        "Radić", "Radman", "Radojković", "Radolović", "Radović", "Radočaj",
        "Radošević", "Raguž", "Rahija", "Rajn", "Rajčić", "Rakela", "Rakuljić",
        "Raljević", "Raspor", "Rastija", "Rađenović", "Rašeta", "Rašić",
        "Ražov", "Rebić", "Rendulić", "Resanović", "Ribarić", "Ribić",
        "Ribičić", "Rijetković", "Risek", "Ritoša", "Ričko", "Roca", "Roce",
        "Rogošić", "Rojnić", "Roso", "Rubeša", "Rubinić", "Rukavina", "Rumora",
        "Sabljak", "Sabol", "Sakač", "Salopek", "Sardelić", "Sedlar",
        "Semialjac", "Seničić", "Seršić", "Sever", "Sikirić", "Simić",
        "Sinožić", "Sirotić", "Skupnjak", "Sladonja", "Slavica", "Smoković",
        "Smolić", "Sobota", "Sokač", "Sokić", "Sokol", "Soldo", "Solomun",
        "Sorić", "Sošić", "Sršen", "Stanić", "Staničić", "Stančin",
        "Starčević", "Stipanović", "Stiperski", "Stojanov", "Stojnić",
        "Stojčević", "Stolnik", "Stošić", "Stražičić", "Strinavić", "Stupalo",
        "Surać", "Svetličić", "Tepeš", "Terlević", "Terzić", "Tešija",
        "Tisaj", "Toić", "Tolj", "Tomić", "Tomičić", "Tomljanović", "Tonc",
        "Topić", "Totić", "Trbović", "Trgovčić", "Triplat", "Trnski",
        "Trutanić", "Tudić", "Tudor", "Tuksar", "Turina", "Turk", "Turudić",
        "Turčinov", "Tuđa", "Tušek", "Tuškan", "Ugrinić", "Ukić", "Urlić",
        "Ušić", "Vaci", "Valentić", "Valjetić", "Varga", "Veić", "Vela",
        "Vidaković", "Vidas", "Vidov", "Vidović", "Viljevac", "Vincetić",
        "Vitasović", "Vižintin", "Vladislavić", "Vlašić", "Vojković",
        "Volarević", "Volarić", "Vorkapić", "Vozila", "Vrabelj", "Vranić",
        "Vrban", "Vretenar", "Vrhovec", "Vugdelija", "Vugec", "Vuk",
        "Vukman", "Vukobratović", "Vuković", "Vukušić", "Vuljak", "Vučetić",
        "Vučin", "Vučković", "Zakinja", "Zanoški", "Zeba", "Zebec", "Zelić",
        "Zgorelec", "Zmaić", "Zrilić", "Zrinski", "Zubčić", "Ćorić", "Ćosić",
        "Ćurić", "Čagalj", "Čargonja", "Čizmić", "Čiš", "Čižmešija", "Čop",
        "Čotić", "Čović", "Čubrić", "Čudić", "Čukman", "Čulina", "Čuljak",
        "Čupić", "Čuček", "Đurašević", "Đurinić", "Šalić", "Šantić", "Šargač",
        "Šarić", "Šarlija", "Šegović", "Šelendić", "Šeparović", "Šestak",
        "Šestan", "Šibalić", "Šimara", "Šimić", "Šimičić", "Šimunić",
        "Šimunović", "Šinković", "Šipek", "Šipić", "Šitum", "Škara", "Škoda",
        "Škrlin", "Škrnički", "Škrtić", "Škugor", "Škunca", "Šokčević",
        "Šošić", "Šoštarić", "Špika", "Špišić", "Špoljarić", "Špralja",
        "Štefanec", "Štefović", "Štifanić", "Štimac", "Štrbac", "Štrljić",
        "Šturlan", "Šunjić", "Šupraha", "Šuran", "Šurbek", "Šurina", "Šverko",
        "Žabjačan", "Žagar", "Žerjav", "Žeželić", "Žic", "Žiković", "Živić",
        "Živković", "Žufika", "Žugec", "Žunec", "Županić", "Žuvela", "Žužić",
    ]



# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats_male = (
        '{{first_name_male}} {{last_name}} {{last_name}}',
        '{{first_name_male}} {{last_name}} {{last_name}}',
        '{{first_name_male}} {{last_name}} {{last_name}}',
        '{{first_name_male}} {{last_name}} {{last_name}}',
        '{{first_name_male}} {{last_name}} {{last_name}}',
        '{{first_name_male}} {{last_name}} {{last_name}}',
        '{{first_name_male}} {{last_name}}',
        '{{first_name_male}} {{prefix}} {{last_name}}',
        '{{first_name_male}} {{last_name}}-{{last_name}}',
        '{{first_name_male}} {{first_name_male}} {{last_name}} {{last_name}}',
    )

    formats_female = (
        '{{first_name_female}} {{last_name}} {{last_name}}',
        '{{first_name_female}} {{last_name}} {{last_name}}',
        '{{first_name_female}} {{last_name}} {{last_name}}',
        '{{first_name_female}} {{last_name}} {{last_name}}',
        '{{first_name_female}} {{last_name}} {{last_name}}',
        '{{first_name_female}} {{last_name}} {{last_name}}',
        '{{first_name_female}} {{last_name}}',
        '{{first_name_female}} {{prefix}} {{last_name}}',
        '{{first_name_female}} {{last_name}}-{{last_name}}',
        '{{first_name_female}} {{first_name_female}} {{last_name}} {{last_name}}',
    )

    formats = formats_male + formats_female

    first_names_male = (
        'Antonio',
        'Jose',
        'Manuel',
        'Francisco',
        'Juan',
        'David',
        'Jose Antonio',
        'Jose Luis',
        'Javier',
        'Jesús',
        'Francisco Javier',
        'Daniel',
        'Carlos',
        'Miguel',
        'Rafael',
        'Jose Manuel',
        'Alejandro',
        'Pedro',
        'Ángel',
        'Miguel Ángel',
        'Jose Maria',
        'Fernando',
        'Luís',
        'Pablo',
        'Sergio',
        'Jorge',
        'Alberto',
        'Juan Carlos',
        'Juan José',
        'Diego',
        'Alvaro',
        'Adrián',
        'Juan Antonio',
        'Enrique',
        'Raul',
        'Ramon',
        'Vicente',
        'Ivan',
        'Ruben',
        'Andrés',
        'Joaquin',
        'Óscar',
        'Juan Manuel',
        'Santiago',
        'Eduardo',
        'Victor',
        'Roberto',
        'Jaime',
        'Francisco Jose',
        'Ignacio',
        'Mario',
        'Alfonso',
        'Salvador',
        'Ricardo',
        'Jordi',
        'Marcos',
        'Emilio',
        'Julian',
        'Julio',
        'Guillermo',
        'Tomás',
        'Gabriel',
        'Agustín',
        'Jose Miguel',
        'Felix',
        'Jose Ramon',
        'Gonzalo',
        'Marc',
        'Mohamed',
        'Joan',
        'Hugo',
        'Ismael',
        'Cristian',
        'Nicolás',
        'Mariano',
        'Josep',
        'Domingo',
        'Samuel',
        'Juan Francisco',
        'Alfredo',
        'Sebastian',
        'Aitor',
        'Jose Carlos',
        'Martin',
        'Felipe',
        'Cesar',
        'Hector',
        'Jose Angel',
        'Jose Ignacio',
        'Victor Manuel',
        'Gregorio',
        'Luis Miguel',
        'Iker',
        'Jose Francisco',
        'Juan Luis',
        'Albert',
        'Lorenzo',
        'Alex',
        'Xavier',
        'Rodrigo')

    first_names_female = (
        'María',
        'Carmen',
        'Ana',
        'Isabel',
        'Dolores',
        'Pilar',
        'Josefa',
        'Teresa',
        'Rosa',
        'Cristina',
        'Ángeles',
        'Antonia',
        'Laura',
        'Francisca',
        'Elena',
        'Mercedes',
        'Luisa',
        'Marta',
        'Concepción',
        'Rosario',
        'Lucía',
        'Juana',
        'Manuela',
        'Sara',
        'Paula',
        'Raquel',
        'Beatriz',
        'Eva',
        'Patricia',
        'Victoria',
        'Rocio',
        'Encarnacion',
        'Julia',
        'Belen',
        'Silvia',
        'Esther',
        'Andrea',
        'Montserrat',
        'Nuria',
        'Angela',
        'Irene',
        'Inmaculada',
        'Mónica',
        'Sandra',
        'Margarita',
        'Yolanda',
        'Alba',
        'Sonia',
        'Alicia',
        'Mar',
        'Susana',
        'Marina',
        'Amparo',
        'Natalia',
        'Nieves',
        'Gloria',
        'Claudia',
        'Soledad',
        'Ines',
        'Lourdes',
        'Verónica',
        'Carolina',
        'Luz',
        'Consuelo',
        'Noelia',
        'Asunción',
        'Lorena',
        'Sofia',
        'Milagros',
        'Catalina',
        'Esperanza',
        'Olga',
        'Alejandra',
        'Carla',
        'Emilia',
        'Fátima',
        'Aurora',
        'Blanca',
        'Magdalena',
        'Miriam',
        'Lidia',
        'Nerea',
        'Clara',
        'Daniela',
        'Anna',
        'Celia',
        'Elisa',
        'Eugenia',
        'Josefina',
        'Virginia',
        'Purificación',
        'Vanesa',
        'Remedios',
        'Trinidad',
        'Gema',
        'Adriana',
        'Vicenta',
        'Mireia',
        'Begoña')

    first_names = first_names_male + first_names_female

    last_names = (
        'Abad', 'Abascal', 'Abella', 'Abellán', 'Abril', 'Acedo', 'Acero',
        'Acevedo', 'Acosta', 'Acuña', 'Adadia', 'Adán', 'Aguado', 'Agudo',
        'Aguilar', 'Aguilera', 'Aguiló', 'Aguirre', 'Agullo', 'Agustí', 'Agustín',
        'Alarcón', 'Alba', 'Alberdi', 'Albero', 'Alberola', 'Alberto', 'Alcalde',
        'Alcalá', 'Alcaraz', 'Alcolea', 'Alcántara', 'Alcázar', 'Alegre', 'Alegria',
        'Alemany', 'Alemán', 'Alfaro', 'Alfonso', 'Aliaga', 'Aller', 'Almagro',
        'Almansa', 'Almazán', 'Almeida', 'Alonso', 'Alsina', 'Alvarado', 'Alvarez',
        'Amador', 'Amat', 'Amaya', 'Amigó', 'Amo', 'Amor', 'Amores',
        'Amorós', 'Anaya', 'Andrade', 'Andres', 'Andreu', 'Andrés', 'Anglada',
        'Anguita', 'Angulo', 'Antón', 'Antúnez', 'Aparicio', 'Aragonés', 'Aragón',
        'Aramburu', 'Arana', 'Aranda', 'Araujo', 'Arce', 'Arco', 'Arcos',
        'Arellano', 'Arenas', 'Arias', 'Ariza', 'Ariño', 'Arjona', 'Armas',
        'Armengol', 'Arnaiz', 'Arnal', 'Arnau', 'Aroca', 'Arranz', 'Arregui',
        'Arribas', 'Arrieta', 'Arroyo', 'Arteaga', 'Artigas', 'Arévalo', 'Asenjo',
        'Asensio', 'Atienza', 'Avilés', 'Ayala', 'Ayllón', 'Ayuso', 'Azcona',
        'Aznar', 'Azorin', 'Badía', 'Baena', 'Baeza', 'Balaguer', 'Ballester',
        'Ballesteros', 'Baquero', 'Barba', 'Barbero', 'Barberá', 'Barceló', 'Barco',
        'Barragán', 'Barral', 'Barranco', 'Barreda', 'Barrena', 'Barrera', 'Barriga',
        'Barrio', 'Barrios', 'Barros', 'Barroso', 'Bartolomé', 'Baró', 'Barón',
        'Bas', 'Bastida', 'Batalla', 'Batlle', 'Bautista', 'Bauzà', 'Bayo',
        'Bayona', 'Bayón', 'Baños', 'Becerra', 'Bejarano', 'Belda', 'Bellido',
        'Bello', 'Belmonte', 'Beltran', 'Beltrán', 'Benavent', 'Benavente', 'Benavides',
        'Benet', 'Benitez', 'Benito', 'Benítez', 'Berenguer', 'Bermejo', 'Bermudez',
        'Bermúdez', 'Bernad', 'Bernal', 'Bernat', 'Berrocal', 'Bertrán', 'Bilbao',
        'Blanca', 'Blanch', 'Blanco', 'Blanes', 'Blasco', 'Blazquez', 'Blázquez',
        'Boada', 'Boix', 'Bolaños', 'Bonet', 'Bonilla', 'Borja', 'Borrego',
        'Borrell', 'Borrás', 'Bosch', 'Botella', 'Bou', 'Bravo', 'Briones',
        'Bru', 'Buendía', 'Bueno', 'Burgos', 'Busquets', 'Bustamante', 'Bustos',
        'Báez', 'Bárcena', 'Caballero', 'Cabanillas', 'Cabañas', 'Cabello', 'Cabeza',
        'Cabezas', 'Cabo', 'Cabrera', 'Cabrero', 'Cadenas', 'Cal', 'Calatayud',
        'Calderon', 'Calderón', 'Calleja', 'Calvet', 'Calvo', 'Calzada', 'Camacho',
        'Camino', 'Campillo', 'Campo', 'Campos', 'Campoy', 'Camps', 'Canales',
        'Canals', 'Canet', 'Cano', 'Cantero', 'Cantón', 'Caparrós', 'Capdevila',
        'Carbajo', 'Carballo', 'Carbonell', 'Carbó', 'Cardona', 'Carlos', 'Carmona',
        'Carnero', 'Caro', 'Carpio', 'Carranza', 'Carrasco', 'Carrera', 'Carreras',
        'Carretero', 'Carreño', 'Carrillo', 'Carrión', 'Carro', 'Carvajal', 'Casado',
        'Casal', 'Casals', 'Casanova', 'Casanovas', 'Casares', 'Casas', 'Cases',
        'Castañeda', 'Castejón', 'Castell', 'Castellanos', 'Castells', 'Castelló', 'Castilla',
        'Castillo', 'Castrillo', 'Castro', 'Catalá', 'Catalán', 'Cazorla', 'Cañas',
        'Cañellas', 'Cañete', 'Cañizares', 'Cepeda', 'Cerdá', 'Cerdán', 'Cerezo',
        'Cerro', 'Cervantes', 'Cervera', 'Chacón', 'Chamorro', 'Chaparro', 'Chaves',
        'Checa', 'Chico', 'Cid', 'Cifuentes', 'Cisneros', 'Clavero', 'Clemente',
        'Cobo', 'Cobos', 'Coca', 'Codina', 'Coello', 'Coll', 'Collado',
        'Colom', 'Coloma', 'Colomer', 'Comas', 'Company', 'Conde', 'Conesa',
        'Contreras', 'Corbacho', 'Cordero', 'Cornejo', 'Corominas', 'Coronado', 'Corral',
        'Correa', 'Cortes', 'Cortina', 'Cortés', 'Costa', 'Crespi', 'Crespo',
        'Criado', 'Cruz', 'Cuadrado', 'Cuenca', 'Cuervo', 'Cuesta', 'Cueto',
        'Cuevas', 'Cuéllar', 'Cáceres', 'Cámara', 'Cánovas', 'Cárdenas', 'Céspedes',
        'Córdoba', 'Cózar', 'Dalmau', 'Daza', 'Delgado', 'Diaz', 'Diego',
        'Diez', 'Diéguez', 'Domingo', 'Dominguez', 'Doménech', 'Domínguez', 'Donaire',
        'Donoso', 'Duarte', 'Dueñas', 'Duque', 'Duran', 'Durán', 'Dávila',
        'Díaz', 'Díez', 'Echevarría', 'Echeverría', 'Egea', 'Elorza', 'Elías',
        'Enríquez', 'Escalona', 'Escamilla', 'Escobar', 'Escolano', 'Escribano', 'Escrivá',
        'Escudero', 'Espada', 'Esparza', 'España', 'Español', 'Espejo', 'Espinosa',
        'Esteban', 'Esteve', 'Estevez', 'Estrada', 'Estévez', 'Exposito', 'Expósito',
        'Fabra', 'Fabregat', 'Fajardo', 'Falcó', 'Falcón', 'Farré', 'Feijoo',
        'Feliu', 'Fernandez', 'Fernández', 'Ferrando', 'Ferrer', 'Ferrera', 'Ferreras',
        'Ferrero', 'Ferrán', 'Ferrández', 'Ferrándiz', 'Figueras', 'Figueroa', 'Figuerola',
        'Fiol', 'Flor', 'Flores', 'Folch', 'Fonseca', 'Font', 'Fortuny',
        'Franch', 'Francisco', 'Franco', 'Frutos', 'Frías', 'Fuente', 'Fuentes',
        'Fuertes', 'Fuster', 'Fábregas', 'Gabaldón', 'Galan', 'Galiano', 'Galindo',
        'Gallardo', 'Gallart', 'Gallego', 'Gallo', 'Galvez', 'Galván', 'Galán',
        'Garay', 'Garcia', 'Garcés', 'García', 'Gargallo', 'Garmendia', 'Garrido',
        'Garriga', 'Garzón', 'Gascón', 'Gaya', 'Gelabert', 'Gibert', 'Gil',
        'Gilabert', 'Gimenez', 'Gimeno', 'Giménez', 'Giner', 'Giralt', 'Girona',
        'Girón', 'Gisbert', 'Godoy', 'Goicoechea', 'Gomez', 'Gomila', 'Gomis',
        'Gonzalez', 'Gonzalo', 'González', 'Gordillo', 'Goñi', 'Gracia', 'Granados',
        'Grande', 'Gras', 'Grau', 'Gual', 'Guardia', 'Guardiola', 'Guerra',
        'Guerrero', 'Guijarro', 'Guillen', 'Guillén', 'Guitart', 'Gutierrez', 'Gutiérrez',
        'Guzman', 'Guzmán', 'Gálvez', 'Gámez', 'Gárate', 'Gómez', 'Haro',
        'Heras', 'Heredia', 'Hernandez', 'Hernando', 'Hernández', 'Herranz', 'Herrera',
        'Herrero', 'Hervia', 'Hervás', 'Hidalgo', 'Hierro', 'Higueras', 'Hoyos',
        'Hoz', 'Huerta', 'Huertas', 'Huguet', 'Hurtado', 'Ibarra', 'Ibañez',
        'Iborra', 'Ibáñez', 'Iglesia', 'Iglesias', 'Infante', 'Iniesta', 'Iriarte',
        'Isern', 'Izaguirre', 'Izquierdo', 'Iñiguez', 'Jara', 'Jaume', 'Jaén',
        'Jerez', 'Jimenez', 'Jiménez', 'Jordá', 'Jordán', 'Jove', 'Jover',
        'Juan', 'Juliá', 'Julián', 'Jurado', 'Juárez', 'Jáuregui', 'Jódar',
        'Lago', 'Laguna', 'Lamas', 'Landa', 'Lara', 'Larrañaga', 'Larrea',
        'Lasa', 'Lastra', 'Leal', 'Ledesma', 'Leiva', 'Leon', 'Lerma',
        'León', 'Lillo', 'Linares', 'Llabrés', 'Lladó', 'Llamas', 'Llano',
        'Llanos', 'Lledó', 'Llobet', 'Llopis', 'Llorens', 'Llorente', 'Lloret',
        'Lluch', 'Lobato', 'Lobo', 'Lopez', 'Lorenzo', 'Losa', 'Losada',
        'Lozano', 'Lucas', 'Lucena', 'Luján', 'Lumbreras', 'Luna', 'Luque',
        'Luz', 'Luís', 'López', 'Machado', 'Macias', 'Macías', 'Madrid',
        'Madrigal', 'Maestre', 'Maldonado', 'Malo', 'Mancebo', 'Manjón', 'Manrique',
        'Manso', 'Manuel', 'Manzanares', 'Manzano', 'Marco', 'Marcos', 'Marin',
        'Mariscal', 'Mariño', 'Marquez', 'Marqués', 'Marti', 'Martin', 'Martinez',
        'Martorell', 'Martí', 'Martín', 'Martínez', 'Marí', 'Marín', 'Mas',
        'Mascaró', 'Mata', 'Matas', 'Mate', 'Mateo', 'Mateos', 'Mateu',
        'Mayo', 'Mayol', 'Mayoral', 'Maza', 'Medina', 'Melero', 'Meléndez',
        'Mena', 'Mendez', 'Mendizábal', 'Mendoza', 'Menendez', 'Menéndez', 'Mercader',
        'Merino', 'Mesa', 'Miguel', 'Milla', 'Millán', 'Mir', 'Miralles',
        'Miranda', 'Miró', 'Moles', 'Molina', 'Moliner', 'Molins', 'Moll',
        'Monreal', 'Montalbán', 'Montaña', 'Montenegro', 'Montero', 'Montes', 'Montesinos',
        'Montoya', 'Montserrat', 'Mora', 'Moraleda', 'Morales', 'Morante', 'Morata',
        'Morcillo', 'Morell', 'Moreno', 'Morera', 'Morillo', 'Morán', 'Mosquera',
        'Moya', 'Mulet', 'Mur', 'Murcia', 'Murillo', 'Muro', 'Muñoz',
        'Mármol', 'Márquez', 'Méndez', 'Mínguez', 'Múgica', 'Múñiz', 'Nadal',
        'Naranjo', 'Narváez', 'Navarrete', 'Navarro', 'Navas', 'Nebot', 'Neira',
        'Nevado', 'Nicolau', 'Nicolás', 'Nieto', 'Niño', 'Nogueira', 'Noguera',
        'Nogués', 'Noriega', 'Novoa', 'Nuñez', 'Núñez', 'Ocaña', 'Ochoa',
        'Ojeda', 'Oliva', 'Olivares', 'Oliver', 'Olivera', 'Oliveras', 'Olivé',
        'Oller', 'Olmedo', 'Olmo', 'Ordóñez', 'Orozco', 'Ortega', 'Ortiz',
        'Ortuño', 'Osorio', 'Osuna', 'Otero', 'Pablo', 'Pacheco', 'Padilla',
        'Pagès', 'Palacio', 'Palacios', 'Palau', 'Pallarès', 'Palma', 'Palmer',
        'Palomar', 'Palomares', 'Palomino', 'Palomo', 'Paniagua', 'Pardo', 'Paredes',
        'Pareja', 'Parejo', 'Parra', 'Pascual', 'Pastor', 'Patiño', 'Pavón',
        'Paz', 'Pazos', 'Pedraza', 'Pedrero', 'Pedro', 'Pedrosa', 'Peinado',
        'Peiró', 'Pelayo', 'Pellicer', 'Peláez', 'Pera', 'Peral', 'Perales',
        'Peralta', 'Perea', 'Pereira', 'Perelló', 'Perera', 'Perez', 'Peña',
        'Peñalver', 'Peñas', 'Pi', 'Pina', 'Pineda', 'Pinedo', 'Pinilla',
        'Pino', 'Pinto', 'Pintor', 'Piquer', 'Pizarro', 'Piña', 'Piñeiro',
        'Piñol', 'Pla', 'Plana', 'Planas', 'Plaza', 'Pol', 'Polo',
        'Pomares', 'Pombo', 'Ponce', 'Pons', 'Pont', 'Porcel', 'Porras',
        'Porta', 'Portero', 'Portillo', 'Posada', 'Pou', 'Poza', 'Pozo',
        'Pozuelo', 'Prada', 'Prado', 'Prat', 'Prats', 'Priego', 'Prieto',
        'Puente', 'Puerta', 'Puga', 'Puig', 'Pujadas', 'Pujol', 'Pulido',
        'Páez', 'Pérez', 'Quero', 'Querol', 'Quesada', 'Quevedo', 'Quintana',
        'Quintanilla', 'Quintero', 'Quiroga', 'Quirós', 'Ramirez', 'Ramis', 'Ramos',
        'Ramírez', 'Ramón', 'Raya', 'Real', 'Rebollo', 'Recio', 'Redondo',
        'Reguera', 'Reig', 'Reina', 'Requena', 'Revilla', 'Rey', 'Reyes',
        'Riba', 'Ribas', 'Ribera', 'Ribes', 'Ricart', 'Rico', 'Riera',
        'Rincón', 'Rios', 'Ripoll', 'Riquelme', 'Rius', 'Rivas', 'Rivera',
        'Rivero', 'Robledo', 'Robles', 'Roca', 'Rocamora', 'Rocha', 'Roda',
        'Rodrigo', 'Rodriguez', 'Rodríguez', 'Roig', 'Rojas', 'Roldan', 'Roldán',
        'Roma', 'Roman', 'Romero', 'Romeu', 'Román', 'Ropero', 'Ros',
        'Rosa', 'Rosado', 'Rosales', 'Rosell', 'Roselló', 'Rosselló', 'Roura',
        'Rovira', 'Royo', 'Rozas', 'Ruano', 'Rubio', 'Rueda', 'Ruiz',
        'Río', 'Ríos', 'Ródenas', 'Saavedra', 'Sabater', 'Sacristán', 'Saez',
        'Sainz', 'Sala', 'Salamanca', 'Salas', 'Salazar', 'Salcedo', 'Saldaña',
        'Sales', 'Salgado', 'Salinas', 'Salmerón', 'Salom', 'Salvador', 'Salvà',
        'Samper', 'Sanabria', 'Sanchez', 'Sancho', 'Sandoval', 'Sanjuan', 'Sanmartín',
        'Sanmiguel', 'Sans', 'Santamaria', 'Santamaría', 'Santana', 'Santiago', 'Santos',
        'Sanz', 'Sarabia', 'Sarmiento', 'Sastre', 'Saura', 'Sebastián', 'Seco',
        'Sedano', 'Segarra', 'Segovia', 'Segura', 'Seguí', 'Serna', 'Serra',
        'Serrano', 'Sevilla', 'Sevillano', 'Sierra', 'Silva', 'Simó', 'Sobrino',
        'Sola', 'Solana', 'Solano', 'Soler', 'Solera', 'Solsona', 'Solé',
        'Solís', 'Somoza', 'Soria', 'Soriano', 'Sosa', 'Sotelo', 'Soto',
        'Suarez', 'Sureda', 'Suárez', 'Sáenz', 'Sáez', 'Sánchez', 'Taboada',
        'Talavera', 'Tamarit', 'Tamayo', 'Tapia', 'Tejada', 'Tejedor', 'Tejera',
        'Tejero', 'Tello', 'Tena', 'Tenorio', 'Terrón', 'Teruel', 'Tirado',
        'Toledo', 'Tolosa', 'Tomas', 'Tomás', 'Tomé', 'Tormo', 'Toro',
        'Torralba', 'Torre', 'Torrecilla', 'Torrens', 'Torrent', 'Torrents', 'Torres',
        'Torrijos', 'Tovar', 'Trillo', 'Trujillo', 'Tudela', 'Tur', 'Téllez',
        'Ugarte', 'Ureña', 'Uriarte', 'Uribe', 'Urrutia', 'Uría', 'Valbuena',
        'Valcárcel', 'Valderrama', 'Valdés', 'Valencia', 'Valenciano', 'Valentín', 'Valenzuela',
        'Valera', 'Valero', 'Vall', 'Valle', 'Vallejo', 'Valls', 'Vallés',
        'Valverde', 'Vaquero', 'Vara', 'Varela', 'Vargas', 'Vazquez', 'Vega',
        'Velasco', 'Velázquez', 'Vendrell', 'Vera', 'Verdejo', 'Verdugo', 'Verdú',
        'Vergara', 'Viana', 'Vicens', 'Vicente', 'Vidal', 'Vigil', 'Vila',
        'Vilalta', 'Vilanova', 'Vilaplana', 'Vilar', 'Villa', 'Villalba', 'Villalobos',
        'Villalonga', 'Villanueva', 'Villar', 'Villaverde', 'Villegas', 'Villena', 'Vives',
        'Vizcaíno', 'Viña', 'Viñas', 'Vázquez', 'Vélez', 'Yuste', 'Yáñez',
        'Zabala', 'Zabaleta', 'Zamora', 'Zamorano', 'Zapata', 'Zaragoza', 'Zorrilla',
        'Zurita', 'Águila', 'Álamo', 'Álvarez', 'Álvaro', 'Ángel', 'Ávila',
    )

    prefixes = ('de', 'del')



# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as InternetProvider


class Provider(InternetProvider):

    free_email_domains = (
        'gmail.com', 'daum.net', 'hotmail.com', 'hanmail.net',
        'naver.com', 'nate.com', 'live.com', 'dreamwiz.com',
    )
    tlds = ('com', 'com', 'com', 'kr', 'kr', 'net', 'org')



# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as AutomotiveProvider


class Provider(AutomotiveProvider):
    # See https://en.wikipedia.org/wiki/Vehicle_registration_plates_of_New_Zealand
    license_formats = (
        # Old plates
        '??%##',
        '??%###',
        '??%###',
        # Three letters since 2002
        'A??%##',
        'B??%##',
        'C??%##',
        'D??%##',
        'E??%##',
        'F??%##',
        'G??%##',
        'H??%##',
        'J??%##',
        'K??%##',
        'L??%##',
        'M??%##',
        # After 2018
        'N??%##',
    )



# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as InternetProvider


class Provider(InternetProvider):

    tlds = ('com', 'com', 'com', 'net', 'org', 'no', 'no', 'no', 'no', 'no')

    replacements = (
        ('æ', 'ae'), ('Æ', 'Ae'),
        ('ø', 'oe'), ('Ø', 'Oe'),
        ('å', 'aa'), ('Å', 'Aa'),
        ('ä', 'ae'), ('Ä', 'Ae'),
        ('ö', 'oe'), ('Ö', 'Oe'),
        ('ü', 'ue'), ('Ü', 'Ue'),
    )



# coding=utf-8


from __future__ import unicode_literals
from .. import Provider as AutomotiveProvider
import string


class Provider(AutomotiveProvider):

    # http://berlin.de/daten/liste-der-kfz-kennzeichen/kfz-kennz-d.csv
    license_plate_prefix = (
        'A', 'AA', 'AB', 'ABI', 'ABG', 'AC', 'AE', 'AIC', 'AK', 'AM', 'AN', 'AÖ', 'AP', 'AS', 'AUR', 'AW', 'AZ', 'B',
        'BA', 'BAD', 'BAR', 'BB', 'BC', 'BD', 'BGL', 'BI', 'BIR', 'BIT', 'BK', 'BL', 'BLK', 'BM', 'BN', 'BO', 'BOR',
        'BOT', 'BP', 'BRA', 'BRB', 'BS', 'BT', 'BTF', 'BÜS', 'BW', 'BWL', 'BYL', 'BZ', 'C', 'CB', 'CE', 'CHA', 'CO',
        'COC', 'COE', 'CUX', 'CW', 'D', 'DA', 'DAH', 'DAN', 'DAU', 'DBR', 'DD', 'DE', 'DEG', 'DEL', 'DGF', 'DH', 'DL',
        'DLG', 'DN', 'Do', 'DON', 'DU', 'DÜW', 'E', 'EA', 'EB', 'EBE', 'ED', 'EE', 'EF', 'EI', 'EIC', 'EL', 'EM', 'EMD',
        'EMS', 'EN', 'ER', 'ERB', 'ERH', 'ERZ', 'ES', 'ESW', 'EU', 'F', 'FB', 'FD', 'FDS', 'FF', 'FFB', 'FG', 'FL',
        'FN', 'FO', 'FR', 'FRG', 'FRI', 'FS', 'FT', 'FÜ', 'G', 'GAP', 'GE', 'GER', 'GF', 'GG', 'GI', 'GL', 'GM', 'GÖ',
        'GP', 'GR', 'GRZ', 'GS', 'GT', 'GTH', 'GÜ', 'GZ', 'H', 'HA', 'HAL', 'HAM', 'HAS', 'HB', 'HBN', 'HD', 'HDH',
        'HE', 'HEF', 'HEI', 'HEL', 'HER', 'HF', 'HG', 'HGW', 'HH', 'HI', 'HL', 'HM', 'HN', 'HO', 'HOL', 'HOM', 'HP',
        'HR', 'HRO', 'HS', 'HSK', 'HST', 'HU', 'HVL', 'HWI', 'HX', 'HZ', 'IGB', 'IK', 'IN', 'IZ', 'J', 'JL', 'K', 'KA',
        'KB', 'KC', 'KE', 'KEH', 'KF', 'KG', 'KH', 'KI', 'KIB', 'KL', 'KLE', 'KN', 'KO', 'KR', 'KS', 'KT', 'KU', 'KÜN',
        'KUS', 'KYF', 'L', 'LA', 'LAU', 'LB', 'LD', 'LDK', 'LDS', 'LER', 'LEV', 'LG', 'LI', 'LIF', 'LIP', 'LL', 'LM',
        'LÖ', 'LOS', 'LRO', 'LSA', 'LSN', 'LU', 'LWL', 'M', 'MA', 'MB', 'MD', 'ME', 'MEI', 'MG', 'MI', 'MIL', 'MK',
        'MKK', 'MM', 'MN', 'MOL', 'MOS', 'MR', 'MS', 'MSH', 'MSP', 'MST', 'MTK', 'MÜ', 'MÜR', 'MVL', 'MYK', 'MZ', 'MZG',
        'N', 'NB', 'ND', 'NDH', 'NE', 'NEA', 'NES', 'NEW', 'NF', 'NI', 'NK', 'NL', 'NM', 'NMS', 'NOH', 'NOM', 'NR',
        'NU', 'NVP', 'NW', 'NWM', 'OA', 'OAL', 'OB', 'OD', 'OE', 'OF', 'OG', 'OH', 'OHA', 'OHV', 'OHZ', 'OL', 'OPR',
        'OS', 'OSL', 'OVP', 'P', 'PA', 'PAF', 'PAN', 'PB', 'PCH', 'PE', 'PF', 'PI', 'PIR', 'PLÖ', 'PM', 'PR', 'PS', 'R',
        'RA', 'RD', 'RE', 'REG', 'RO', 'ROS', 'ROW', 'RP', 'RPL', 'RS', 'RT', 'RÜD', 'RÜG', 'RV', 'RW', 'RZ', 'S',
        'SAD', 'SAL', 'SAW', 'SB', 'SC', 'SDL', 'SE', 'SG', 'SH', 'SHA', 'SHG', 'SHK', 'SHL', 'SI', 'SIG', 'SIM', 'SK',
        'SL', 'SLF', 'SLK', 'SLS', 'SM', 'SN', 'SO', 'SOK', 'SÖM', 'SON', 'SP', 'SPN', 'SR', 'ST', 'STA', 'STD', 'SU',
        'SÜW', 'SW', 'SZ', 'TDO', 'TBB', 'TF', 'TG', 'THL', 'THW', 'TIR', 'TÖL', 'TR', 'TS', 'TÜ', 'TUT', 'UE', 'UL',
        'UM', 'UN', 'V', 'VB', 'VEC', 'VER', 'VIE', 'VK', 'VR', 'VS', 'W', 'WAF', 'WAK', 'WB', 'WE', 'WEN', 'WES', 'WF',
        'WHV', 'WI', 'WIL', 'WL', 'WM', 'WN', 'WND', 'WO', 'WOB', 'WST', 'WT', 'WTM', 'WÜ', 'WUG', 'WUN', 'WW', 'WZ',
        'Y', 'Z', 'ZW',
    )

    license_plate_suffix = (
        '-??-%@@@',
        '-?-%@@@',
    )

    def license_plate(self):
        return self.random_element(self.license_plate_prefix) + \
               self.lexify(self.numerify(self.random_element(self.license_plate_suffix)), string.ascii_uppercase)
